// Generated by https://github.com/juliettef/IconFontCppHeaders script GenerateIconFontCppHeaders.py for language C++11
// from icons.yml
// for use with fa-light-300.ttf, fa-regular-400.ttf, fa-solid-900.ttf
#pragma once

#define FONT_ICON_FILE_NAME_FAL "fa-light-300.ttf"
#define FONT_ICON_FILE_NAME_FAR "fa-regular-400.ttf"
#define FONT_ICON_FILE_NAME_FAS "fa-solid-900.ttf"

#define ICON_MIN_FA 0xe000
#define ICON_MAX_FA 0xf8ff
#define ICON_FA_ABACUS u8"\uf640"
#define ICON_FA_ACORN u8"\uf6ae"
#define ICON_FA_AD u8"\uf641"
#define ICON_FA_ADDRESS_BOOK u8"\uf2b9"
#define ICON_FA_ADDRESS_CARD u8"\uf2bb"
#define ICON_FA_ADJUST u8"\uf042"
#define ICON_FA_AIR_CONDITIONER u8"\uf8f4"
#define ICON_FA_AIR_FRESHENER u8"\uf5d0"
#define ICON_FA_ALARM_CLOCK u8"\uf34e"
#define ICON_FA_ALARM_EXCLAMATION u8"\uf843"
#define ICON_FA_ALARM_PLUS u8"\uf844"
#define ICON_FA_ALARM_SNOOZE u8"\uf845"
#define ICON_FA_ALBUM u8"\uf89f"
#define ICON_FA_ALBUM_COLLECTION u8"\uf8a0"
#define ICON_FA_ALICORN u8"\uf6b0"
#define ICON_FA_ALIEN u8"\uf8f5"
#define ICON_FA_ALIEN_MONSTER u8"\uf8f6"
#define ICON_FA_ALIGN_CENTER u8"\uf037"
#define ICON_FA_ALIGN_JUSTIFY u8"\uf039"
#define ICON_FA_ALIGN_LEFT u8"\uf036"
#define ICON_FA_ALIGN_RIGHT u8"\uf038"
#define ICON_FA_ALIGN_SLASH u8"\uf846"
#define ICON_FA_ALLERGIES u8"\uf461"
#define ICON_FA_AMBULANCE u8"\uf0f9"
#define ICON_FA_AMERICAN_SIGN_LANGUAGE_INTERPRETING u8"\uf2a3"
#define ICON_FA_AMP_GUITAR u8"\uf8a1"
#define ICON_FA_ANALYTICS u8"\uf643"
#define ICON_FA_ANCHOR u8"\uf13d"
#define ICON_FA_ANGEL u8"\uf779"
#define ICON_FA_ANGLE_DOUBLE_DOWN u8"\uf103"
#define ICON_FA_ANGLE_DOUBLE_LEFT u8"\uf100"
#define ICON_FA_ANGLE_DOUBLE_RIGHT u8"\uf101"
#define ICON_FA_ANGLE_DOUBLE_UP u8"\uf102"
#define ICON_FA_ANGLE_DOWN u8"\uf107"
#define ICON_FA_ANGLE_LEFT u8"\uf104"
#define ICON_FA_ANGLE_RIGHT u8"\uf105"
#define ICON_FA_ANGLE_UP u8"\uf106"
#define ICON_FA_ANGRY u8"\uf556"
#define ICON_FA_ANKH u8"\uf644"
#define ICON_FA_APPLE_ALT u8"\uf5d1"
#define ICON_FA_APPLE_CRATE u8"\uf6b1"
#define ICON_FA_ARCHIVE u8"\uf187"
#define ICON_FA_ARCHWAY u8"\uf557"
#define ICON_FA_ARROW_ALT_CIRCLE_DOWN u8"\uf358"
#define ICON_FA_ARROW_ALT_CIRCLE_LEFT u8"\uf359"
#define ICON_FA_ARROW_ALT_CIRCLE_RIGHT u8"\uf35a"
#define ICON_FA_ARROW_ALT_CIRCLE_UP u8"\uf35b"
#define ICON_FA_ARROW_ALT_DOWN u8"\uf354"
#define ICON_FA_ARROW_ALT_FROM_BOTTOM u8"\uf346"
#define ICON_FA_ARROW_ALT_FROM_LEFT u8"\uf347"
#define ICON_FA_ARROW_ALT_FROM_RIGHT u8"\uf348"
#define ICON_FA_ARROW_ALT_FROM_TOP u8"\uf349"
#define ICON_FA_ARROW_ALT_LEFT u8"\uf355"
#define ICON_FA_ARROW_ALT_RIGHT u8"\uf356"
#define ICON_FA_ARROW_ALT_SQUARE_DOWN u8"\uf350"
#define ICON_FA_ARROW_ALT_SQUARE_LEFT u8"\uf351"
#define ICON_FA_ARROW_ALT_SQUARE_RIGHT u8"\uf352"
#define ICON_FA_ARROW_ALT_SQUARE_UP u8"\uf353"
#define ICON_FA_ARROW_ALT_TO_BOTTOM u8"\uf34a"
#define ICON_FA_ARROW_ALT_TO_LEFT u8"\uf34b"
#define ICON_FA_ARROW_ALT_TO_RIGHT u8"\uf34c"
#define ICON_FA_ARROW_ALT_TO_TOP u8"\uf34d"
#define ICON_FA_ARROW_ALT_UP u8"\uf357"
#define ICON_FA_ARROW_CIRCLE_DOWN u8"\uf0ab"
#define ICON_FA_ARROW_CIRCLE_LEFT u8"\uf0a8"
#define ICON_FA_ARROW_CIRCLE_RIGHT u8"\uf0a9"
#define ICON_FA_ARROW_CIRCLE_UP u8"\uf0aa"
#define ICON_FA_ARROW_DOWN u8"\uf063"
#define ICON_FA_ARROW_FROM_BOTTOM u8"\uf342"
#define ICON_FA_ARROW_FROM_LEFT u8"\uf343"
#define ICON_FA_ARROW_FROM_RIGHT u8"\uf344"
#define ICON_FA_ARROW_FROM_TOP u8"\uf345"
#define ICON_FA_ARROW_LEFT u8"\uf060"
#define ICON_FA_ARROW_RIGHT u8"\uf061"
#define ICON_FA_ARROW_SQUARE_DOWN u8"\uf339"
#define ICON_FA_ARROW_SQUARE_LEFT u8"\uf33a"
#define ICON_FA_ARROW_SQUARE_RIGHT u8"\uf33b"
#define ICON_FA_ARROW_SQUARE_UP u8"\uf33c"
#define ICON_FA_ARROW_TO_BOTTOM u8"\uf33d"
#define ICON_FA_ARROW_TO_LEFT u8"\uf33e"
#define ICON_FA_ARROW_TO_RIGHT u8"\uf340"
#define ICON_FA_ARROW_TO_TOP u8"\uf341"
#define ICON_FA_ARROW_UP u8"\uf062"
#define ICON_FA_ARROWS u8"\uf047"
#define ICON_FA_ARROWS_ALT u8"\uf0b2"
#define ICON_FA_ARROWS_ALT_H u8"\uf337"
#define ICON_FA_ARROWS_ALT_V u8"\uf338"
#define ICON_FA_ARROWS_H u8"\uf07e"
#define ICON_FA_ARROWS_V u8"\uf07d"
#define ICON_FA_ASSISTIVE_LISTENING_SYSTEMS u8"\uf2a2"
#define ICON_FA_ASTERISK u8"\uf069"
#define ICON_FA_AT u8"\uf1fa"
#define ICON_FA_ATLAS u8"\uf558"
#define ICON_FA_ATOM u8"\uf5d2"
#define ICON_FA_ATOM_ALT u8"\uf5d3"
#define ICON_FA_AUDIO_DESCRIPTION u8"\uf29e"
#define ICON_FA_AWARD u8"\uf559"
#define ICON_FA_AXE u8"\uf6b2"
#define ICON_FA_AXE_BATTLE u8"\uf6b3"
#define ICON_FA_BABY u8"\uf77c"
#define ICON_FA_BABY_CARRIAGE u8"\uf77d"
#define ICON_FA_BACKPACK u8"\uf5d4"
#define ICON_FA_BACKSPACE u8"\uf55a"
#define ICON_FA_BACKWARD u8"\uf04a"
#define ICON_FA_BACON u8"\uf7e5"
#define ICON_FA_BACTERIA u8"\ue059"
#define ICON_FA_BACTERIUM u8"\ue05a"
#define ICON_FA_BADGE u8"\uf335"
#define ICON_FA_BADGE_CHECK u8"\uf336"
#define ICON_FA_BADGE_DOLLAR u8"\uf645"
#define ICON_FA_BADGE_PERCENT u8"\uf646"
#define ICON_FA_BADGE_SHERIFF u8"\uf8a2"
#define ICON_FA_BADGER_HONEY u8"\uf6b4"
#define ICON_FA_BAGS_SHOPPING u8"\uf847"
#define ICON_FA_BAHAI u8"\uf666"
#define ICON_FA_BALANCE_SCALE u8"\uf24e"
#define ICON_FA_BALANCE_SCALE_LEFT u8"\uf515"
#define ICON_FA_BALANCE_SCALE_RIGHT u8"\uf516"
#define ICON_FA_BALL_PILE u8"\uf77e"
#define ICON_FA_BALLOT u8"\uf732"
#define ICON_FA_BALLOT_CHECK u8"\uf733"
#define ICON_FA_BAN u8"\uf05e"
#define ICON_FA_BAND_AID u8"\uf462"
#define ICON_FA_BANJO u8"\uf8a3"
#define ICON_FA_BARCODE u8"\uf02a"
#define ICON_FA_BARCODE_ALT u8"\uf463"
#define ICON_FA_BARCODE_READ u8"\uf464"
#define ICON_FA_BARCODE_SCAN u8"\uf465"
#define ICON_FA_BARS u8"\uf0c9"
#define ICON_FA_BASEBALL u8"\uf432"
#define ICON_FA_BASEBALL_BALL u8"\uf433"
#define ICON_FA_BASKETBALL_BALL u8"\uf434"
#define ICON_FA_BASKETBALL_HOOP u8"\uf435"
#define ICON_FA_BAT u8"\uf6b5"
#define ICON_FA_BATH u8"\uf2cd"
#define ICON_FA_BATTERY_BOLT u8"\uf376"
#define ICON_FA_BATTERY_EMPTY u8"\uf244"
#define ICON_FA_BATTERY_FULL u8"\uf240"
#define ICON_FA_BATTERY_HALF u8"\uf242"
#define ICON_FA_BATTERY_QUARTER u8"\uf243"
#define ICON_FA_BATTERY_SLASH u8"\uf377"
#define ICON_FA_BATTERY_THREE_QUARTERS u8"\uf241"
#define ICON_FA_BED u8"\uf236"
#define ICON_FA_BED_ALT u8"\uf8f7"
#define ICON_FA_BED_BUNK u8"\uf8f8"
#define ICON_FA_BED_EMPTY u8"\uf8f9"
#define ICON_FA_BEER u8"\uf0fc"
#define ICON_FA_BELL u8"\uf0f3"
#define ICON_FA_BELL_EXCLAMATION u8"\uf848"
#define ICON_FA_BELL_ON u8"\uf8fa"
#define ICON_FA_BELL_PLUS u8"\uf849"
#define ICON_FA_BELL_SCHOOL u8"\uf5d5"
#define ICON_FA_BELL_SCHOOL_SLASH u8"\uf5d6"
#define ICON_FA_BELL_SLASH u8"\uf1f6"
#define ICON_FA_BELLS u8"\uf77f"
#define ICON_FA_BETAMAX u8"\uf8a4"
#define ICON_FA_BEZIER_CURVE u8"\uf55b"
#define ICON_FA_BIBLE u8"\uf647"
#define ICON_FA_BICYCLE u8"\uf206"
#define ICON_FA_BIKING u8"\uf84a"
#define ICON_FA_BIKING_MOUNTAIN u8"\uf84b"
#define ICON_FA_BINOCULARS u8"\uf1e5"
#define ICON_FA_BIOHAZARD u8"\uf780"
#define ICON_FA_BIRTHDAY_CAKE u8"\uf1fd"
#define ICON_FA_BLANKET u8"\uf498"
#define ICON_FA_BLENDER u8"\uf517"
#define ICON_FA_BLENDER_PHONE u8"\uf6b6"
#define ICON_FA_BLIND u8"\uf29d"
#define ICON_FA_BLINDS u8"\uf8fb"
#define ICON_FA_BLINDS_OPEN u8"\uf8fc"
#define ICON_FA_BLINDS_RAISED u8"\uf8fd"
#define ICON_FA_BLOG u8"\uf781"
#define ICON_FA_BOLD u8"\uf032"
#define ICON_FA_BOLT u8"\uf0e7"
#define ICON_FA_BOMB u8"\uf1e2"
#define ICON_FA_BONE u8"\uf5d7"
#define ICON_FA_BONE_BREAK u8"\uf5d8"
#define ICON_FA_BONG u8"\uf55c"
#define ICON_FA_BOOK u8"\uf02d"
#define ICON_FA_BOOK_ALT u8"\uf5d9"
#define ICON_FA_BOOK_DEAD u8"\uf6b7"
#define ICON_FA_BOOK_HEART u8"\uf499"
#define ICON_FA_BOOK_MEDICAL u8"\uf7e6"
#define ICON_FA_BOOK_OPEN u8"\uf518"
#define ICON_FA_BOOK_READER u8"\uf5da"
#define ICON_FA_BOOK_SPELLS u8"\uf6b8"
#define ICON_FA_BOOK_USER u8"\uf7e7"
#define ICON_FA_BOOKMARK u8"\uf02e"
#define ICON_FA_BOOKS u8"\uf5db"
#define ICON_FA_BOOKS_MEDICAL u8"\uf7e8"
#define ICON_FA_BOOMBOX u8"\uf8a5"
#define ICON_FA_BOOT u8"\uf782"
#define ICON_FA_BOOTH_CURTAIN u8"\uf734"
#define ICON_FA_BORDER_ALL u8"\uf84c"
#define ICON_FA_BORDER_BOTTOM u8"\uf84d"
#define ICON_FA_BORDER_CENTER_H u8"\uf89c"
#define ICON_FA_BORDER_CENTER_V u8"\uf89d"
#define ICON_FA_BORDER_INNER u8"\uf84e"
#define ICON_FA_BORDER_LEFT u8"\uf84f"
#define ICON_FA_BORDER_NONE u8"\uf850"
#define ICON_FA_BORDER_OUTER u8"\uf851"
#define ICON_FA_BORDER_RIGHT u8"\uf852"
#define ICON_FA_BORDER_STYLE u8"\uf853"
#define ICON_FA_BORDER_STYLE_ALT u8"\uf854"
#define ICON_FA_BORDER_TOP u8"\uf855"
#define ICON_FA_BOW_ARROW u8"\uf6b9"
#define ICON_FA_BOWLING_BALL u8"\uf436"
#define ICON_FA_BOWLING_PINS u8"\uf437"
#define ICON_FA_BOX u8"\uf466"
#define ICON_FA_BOX_ALT u8"\uf49a"
#define ICON_FA_BOX_BALLOT u8"\uf735"
#define ICON_FA_BOX_CHECK u8"\uf467"
#define ICON_FA_BOX_FRAGILE u8"\uf49b"
#define ICON_FA_BOX_FULL u8"\uf49c"
#define ICON_FA_BOX_HEART u8"\uf49d"
#define ICON_FA_BOX_OPEN u8"\uf49e"
#define ICON_FA_BOX_TISSUE u8"\ue05b"
#define ICON_FA_BOX_UP u8"\uf49f"
#define ICON_FA_BOX_USD u8"\uf4a0"
#define ICON_FA_BOXES u8"\uf468"
#define ICON_FA_BOXES_ALT u8"\uf4a1"
#define ICON_FA_BOXING_GLOVE u8"\uf438"
#define ICON_FA_BRACKETS u8"\uf7e9"
#define ICON_FA_BRACKETS_CURLY u8"\uf7ea"
#define ICON_FA_BRAILLE u8"\uf2a1"
#define ICON_FA_BRAIN u8"\uf5dc"
#define ICON_FA_BREAD_LOAF u8"\uf7eb"
#define ICON_FA_BREAD_SLICE u8"\uf7ec"
#define ICON_FA_BRIEFCASE u8"\uf0b1"
#define ICON_FA_BRIEFCASE_MEDICAL u8"\uf469"
#define ICON_FA_BRING_FORWARD u8"\uf856"
#define ICON_FA_BRING_FRONT u8"\uf857"
#define ICON_FA_BROADCAST_TOWER u8"\uf519"
#define ICON_FA_BROOM u8"\uf51a"
#define ICON_FA_BROWSER u8"\uf37e"
#define ICON_FA_BRUSH u8"\uf55d"
#define ICON_FA_BUG u8"\uf188"
#define ICON_FA_BUILDING u8"\uf1ad"
#define ICON_FA_BULLHORN u8"\uf0a1"
#define ICON_FA_BULLSEYE u8"\uf140"
#define ICON_FA_BULLSEYE_ARROW u8"\uf648"
#define ICON_FA_BULLSEYE_POINTER u8"\uf649"
#define ICON_FA_BURGER_SODA u8"\uf858"
#define ICON_FA_BURN u8"\uf46a"
#define ICON_FA_BURRITO u8"\uf7ed"
#define ICON_FA_BUS u8"\uf207"
#define ICON_FA_BUS_ALT u8"\uf55e"
#define ICON_FA_BUS_SCHOOL u8"\uf5dd"
#define ICON_FA_BUSINESS_TIME u8"\uf64a"
#define ICON_FA_CABINET_FILING u8"\uf64b"
#define ICON_FA_CACTUS u8"\uf8a7"
#define ICON_FA_CALCULATOR u8"\uf1ec"
#define ICON_FA_CALCULATOR_ALT u8"\uf64c"
#define ICON_FA_CALENDAR u8"\uf133"
#define ICON_FA_CALENDAR_ALT u8"\uf073"
#define ICON_FA_CALENDAR_CHECK u8"\uf274"
#define ICON_FA_CALENDAR_DAY u8"\uf783"
#define ICON_FA_CALENDAR_EDIT u8"\uf333"
#define ICON_FA_CALENDAR_EXCLAMATION u8"\uf334"
#define ICON_FA_CALENDAR_MINUS u8"\uf272"
#define ICON_FA_CALENDAR_PLUS u8"\uf271"
#define ICON_FA_CALENDAR_STAR u8"\uf736"
#define ICON_FA_CALENDAR_TIMES u8"\uf273"
#define ICON_FA_CALENDAR_WEEK u8"\uf784"
#define ICON_FA_CAMCORDER u8"\uf8a8"
#define ICON_FA_CAMERA u8"\uf030"
#define ICON_FA_CAMERA_ALT u8"\uf332"
#define ICON_FA_CAMERA_HOME u8"\uf8fe"
#define ICON_FA_CAMERA_MOVIE u8"\uf8a9"
#define ICON_FA_CAMERA_POLAROID u8"\uf8aa"
#define ICON_FA_CAMERA_RETRO u8"\uf083"
#define ICON_FA_CAMPFIRE u8"\uf6ba"
#define ICON_FA_CAMPGROUND u8"\uf6bb"
#define ICON_FA_CANDLE_HOLDER u8"\uf6bc"
#define ICON_FA_CANDY_CANE u8"\uf786"
#define ICON_FA_CANDY_CORN u8"\uf6bd"
#define ICON_FA_CANNABIS u8"\uf55f"
#define ICON_FA_CAPSULES u8"\uf46b"
#define ICON_FA_CAR u8"\uf1b9"
#define ICON_FA_CAR_ALT u8"\uf5de"
#define ICON_FA_CAR_BATTERY u8"\uf5df"
#define ICON_FA_CAR_BUILDING u8"\uf859"
#define ICON_FA_CAR_BUMP u8"\uf5e0"
#define ICON_FA_CAR_BUS u8"\uf85a"
#define ICON_FA_CAR_CRASH u8"\uf5e1"
#define ICON_FA_CAR_GARAGE u8"\uf5e2"
#define ICON_FA_CAR_MECHANIC u8"\uf5e3"
#define ICON_FA_CAR_SIDE u8"\uf5e4"
#define ICON_FA_CAR_TILT u8"\uf5e5"
#define ICON_FA_CAR_WASH u8"\uf5e6"
#define ICON_FA_CARAVAN u8"\uf8ff"
#define ICON_FA_CARAVAN_ALT u8"\ue000"
#define ICON_FA_CARET_CIRCLE_DOWN u8"\uf32d"
#define ICON_FA_CARET_CIRCLE_LEFT u8"\uf32e"
#define ICON_FA_CARET_CIRCLE_RIGHT u8"\uf330"
#define ICON_FA_CARET_CIRCLE_UP u8"\uf331"
#define ICON_FA_CARET_DOWN u8"\uf0d7"
#define ICON_FA_CARET_LEFT u8"\uf0d9"
#define ICON_FA_CARET_RIGHT u8"\uf0da"
#define ICON_FA_CARET_SQUARE_DOWN u8"\uf150"
#define ICON_FA_CARET_SQUARE_LEFT u8"\uf191"
#define ICON_FA_CARET_SQUARE_RIGHT u8"\uf152"
#define ICON_FA_CARET_SQUARE_UP u8"\uf151"
#define ICON_FA_CARET_UP u8"\uf0d8"
#define ICON_FA_CARROT u8"\uf787"
#define ICON_FA_CARS u8"\uf85b"
#define ICON_FA_CART_ARROW_DOWN u8"\uf218"
#define ICON_FA_CART_PLUS u8"\uf217"
#define ICON_FA_CASH_REGISTER u8"\uf788"
#define ICON_FA_CASSETTE_TAPE u8"\uf8ab"
#define ICON_FA_CAT u8"\uf6be"
#define ICON_FA_CAT_SPACE u8"\ue001"
#define ICON_FA_CAULDRON u8"\uf6bf"
#define ICON_FA_CCTV u8"\uf8ac"
#define ICON_FA_CERTIFICATE u8"\uf0a3"
#define ICON_FA_CHAIR u8"\uf6c0"
#define ICON_FA_CHAIR_OFFICE u8"\uf6c1"
#define ICON_FA_CHALKBOARD u8"\uf51b"
#define ICON_FA_CHALKBOARD_TEACHER u8"\uf51c"
#define ICON_FA_CHARGING_STATION u8"\uf5e7"
#define ICON_FA_CHART_AREA u8"\uf1fe"
#define ICON_FA_CHART_BAR u8"\uf080"
#define ICON_FA_CHART_LINE u8"\uf201"
#define ICON_FA_CHART_LINE_DOWN u8"\uf64d"
#define ICON_FA_CHART_NETWORK u8"\uf78a"
#define ICON_FA_CHART_PIE u8"\uf200"
#define ICON_FA_CHART_PIE_ALT u8"\uf64e"
#define ICON_FA_CHART_SCATTER u8"\uf7ee"
#define ICON_FA_CHECK u8"\uf00c"
#define ICON_FA_CHECK_CIRCLE u8"\uf058"
#define ICON_FA_CHECK_DOUBLE u8"\uf560"
#define ICON_FA_CHECK_SQUARE u8"\uf14a"
#define ICON_FA_CHEESE u8"\uf7ef"
#define ICON_FA_CHEESE_SWISS u8"\uf7f0"
#define ICON_FA_CHEESEBURGER u8"\uf7f1"
#define ICON_FA_CHESS u8"\uf439"
#define ICON_FA_CHESS_BISHOP u8"\uf43a"
#define ICON_FA_CHESS_BISHOP_ALT u8"\uf43b"
#define ICON_FA_CHESS_BOARD u8"\uf43c"
#define ICON_FA_CHESS_CLOCK u8"\uf43d"
#define ICON_FA_CHESS_CLOCK_ALT u8"\uf43e"
#define ICON_FA_CHESS_KING u8"\uf43f"
#define ICON_FA_CHESS_KING_ALT u8"\uf440"
#define ICON_FA_CHESS_KNIGHT u8"\uf441"
#define ICON_FA_CHESS_KNIGHT_ALT u8"\uf442"
#define ICON_FA_CHESS_PAWN u8"\uf443"
#define ICON_FA_CHESS_PAWN_ALT u8"\uf444"
#define ICON_FA_CHESS_QUEEN u8"\uf445"
#define ICON_FA_CHESS_QUEEN_ALT u8"\uf446"
#define ICON_FA_CHESS_ROOK u8"\uf447"
#define ICON_FA_CHESS_ROOK_ALT u8"\uf448"
#define ICON_FA_CHEVRON_CIRCLE_DOWN u8"\uf13a"
#define ICON_FA_CHEVRON_CIRCLE_LEFT u8"\uf137"
#define ICON_FA_CHEVRON_CIRCLE_RIGHT u8"\uf138"
#define ICON_FA_CHEVRON_CIRCLE_UP u8"\uf139"
#define ICON_FA_CHEVRON_DOUBLE_DOWN u8"\uf322"
#define ICON_FA_CHEVRON_DOUBLE_LEFT u8"\uf323"
#define ICON_FA_CHEVRON_DOUBLE_RIGHT u8"\uf324"
#define ICON_FA_CHEVRON_DOUBLE_UP u8"\uf325"
#define ICON_FA_CHEVRON_DOWN u8"\uf078"
#define ICON_FA_CHEVRON_LEFT u8"\uf053"
#define ICON_FA_CHEVRON_RIGHT u8"\uf054"
#define ICON_FA_CHEVRON_SQUARE_DOWN u8"\uf329"
#define ICON_FA_CHEVRON_SQUARE_LEFT u8"\uf32a"
#define ICON_FA_CHEVRON_SQUARE_RIGHT u8"\uf32b"
#define ICON_FA_CHEVRON_SQUARE_UP u8"\uf32c"
#define ICON_FA_CHEVRON_UP u8"\uf077"
#define ICON_FA_CHILD u8"\uf1ae"
#define ICON_FA_CHIMNEY u8"\uf78b"
#define ICON_FA_CHURCH u8"\uf51d"
#define ICON_FA_CIRCLE u8"\uf111"
#define ICON_FA_CIRCLE_NOTCH u8"\uf1ce"
#define ICON_FA_CITY u8"\uf64f"
#define ICON_FA_CLARINET u8"\uf8ad"
#define ICON_FA_CLAW_MARKS u8"\uf6c2"
#define ICON_FA_CLINIC_MEDICAL u8"\uf7f2"
#define ICON_FA_CLIPBOARD u8"\uf328"
#define ICON_FA_CLIPBOARD_CHECK u8"\uf46c"
#define ICON_FA_CLIPBOARD_LIST u8"\uf46d"
#define ICON_FA_CLIPBOARD_LIST_CHECK u8"\uf737"
#define ICON_FA_CLIPBOARD_PRESCRIPTION u8"\uf5e8"
#define ICON_FA_CLIPBOARD_USER u8"\uf7f3"
#define ICON_FA_CLOCK u8"\uf017"
#define ICON_FA_CLONE u8"\uf24d"
#define ICON_FA_CLOSED_CAPTIONING u8"\uf20a"
#define ICON_FA_CLOUD u8"\uf0c2"
#define ICON_FA_CLOUD_DOWNLOAD u8"\uf0ed"
#define ICON_FA_CLOUD_DOWNLOAD_ALT u8"\uf381"
#define ICON_FA_CLOUD_DRIZZLE u8"\uf738"
#define ICON_FA_CLOUD_HAIL u8"\uf739"
#define ICON_FA_CLOUD_HAIL_MIXED u8"\uf73a"
#define ICON_FA_CLOUD_MEATBALL u8"\uf73b"
#define ICON_FA_CLOUD_MOON u8"\uf6c3"
#define ICON_FA_CLOUD_MOON_RAIN u8"\uf73c"
#define ICON_FA_CLOUD_MUSIC u8"\uf8ae"
#define ICON_FA_CLOUD_RAIN u8"\uf73d"
#define ICON_FA_CLOUD_RAINBOW u8"\uf73e"
#define ICON_FA_CLOUD_SHOWERS u8"\uf73f"
#define ICON_FA_CLOUD_SHOWERS_HEAVY u8"\uf740"
#define ICON_FA_CLOUD_SLEET u8"\uf741"
#define ICON_FA_CLOUD_SNOW u8"\uf742"
#define ICON_FA_CLOUD_SUN u8"\uf6c4"
#define ICON_FA_CLOUD_SUN_RAIN u8"\uf743"
#define ICON_FA_CLOUD_UPLOAD u8"\uf0ee"
#define ICON_FA_CLOUD_UPLOAD_ALT u8"\uf382"
#define ICON_FA_CLOUDS u8"\uf744"
#define ICON_FA_CLOUDS_MOON u8"\uf745"
#define ICON_FA_CLOUDS_SUN u8"\uf746"
#define ICON_FA_CLUB u8"\uf327"
#define ICON_FA_COCKTAIL u8"\uf561"
#define ICON_FA_CODE u8"\uf121"
#define ICON_FA_CODE_BRANCH u8"\uf126"
#define ICON_FA_CODE_COMMIT u8"\uf386"
#define ICON_FA_CODE_MERGE u8"\uf387"
#define ICON_FA_COFFEE u8"\uf0f4"
#define ICON_FA_COFFEE_POT u8"\ue002"
#define ICON_FA_COFFEE_TOGO u8"\uf6c5"
#define ICON_FA_COFFIN u8"\uf6c6"
#define ICON_FA_COFFIN_CROSS u8"\ue051"
#define ICON_FA_COG u8"\uf013"
#define ICON_FA_COGS u8"\uf085"
#define ICON_FA_COIN u8"\uf85c"
#define ICON_FA_COINS u8"\uf51e"
#define ICON_FA_COLUMNS u8"\uf0db"
#define ICON_FA_COMET u8"\ue003"
#define ICON_FA_COMMENT u8"\uf075"
#define ICON_FA_COMMENT_ALT u8"\uf27a"
#define ICON_FA_COMMENT_ALT_CHECK u8"\uf4a2"
#define ICON_FA_COMMENT_ALT_DOLLAR u8"\uf650"
#define ICON_FA_COMMENT_ALT_DOTS u8"\uf4a3"
#define ICON_FA_COMMENT_ALT_EDIT u8"\uf4a4"
#define ICON_FA_COMMENT_ALT_EXCLAMATION u8"\uf4a5"
#define ICON_FA_COMMENT_ALT_LINES u8"\uf4a6"
#define ICON_FA_COMMENT_ALT_MEDICAL u8"\uf7f4"
#define ICON_FA_COMMENT_ALT_MINUS u8"\uf4a7"
#define ICON_FA_COMMENT_ALT_MUSIC u8"\uf8af"
#define ICON_FA_COMMENT_ALT_PLUS u8"\uf4a8"
#define ICON_FA_COMMENT_ALT_SLASH u8"\uf4a9"
#define ICON_FA_COMMENT_ALT_SMILE u8"\uf4aa"
#define ICON_FA_COMMENT_ALT_TIMES u8"\uf4ab"
#define ICON_FA_COMMENT_CHECK u8"\uf4ac"
#define ICON_FA_COMMENT_DOLLAR u8"\uf651"
#define ICON_FA_COMMENT_DOTS u8"\uf4ad"
#define ICON_FA_COMMENT_EDIT u8"\uf4ae"
#define ICON_FA_COMMENT_EXCLAMATION u8"\uf4af"
#define ICON_FA_COMMENT_LINES u8"\uf4b0"
#define ICON_FA_COMMENT_MEDICAL u8"\uf7f5"
#define ICON_FA_COMMENT_MINUS u8"\uf4b1"
#define ICON_FA_COMMENT_MUSIC u8"\uf8b0"
#define ICON_FA_COMMENT_PLUS u8"\uf4b2"
#define ICON_FA_COMMENT_SLASH u8"\uf4b3"
#define ICON_FA_COMMENT_SMILE u8"\uf4b4"
#define ICON_FA_COMMENT_TIMES u8"\uf4b5"
#define ICON_FA_COMMENTS u8"\uf086"
#define ICON_FA_COMMENTS_ALT u8"\uf4b6"
#define ICON_FA_COMMENTS_ALT_DOLLAR u8"\uf652"
#define ICON_FA_COMMENTS_DOLLAR u8"\uf653"
#define ICON_FA_COMPACT_DISC u8"\uf51f"
#define ICON_FA_COMPASS u8"\uf14e"
#define ICON_FA_COMPASS_SLASH u8"\uf5e9"
#define ICON_FA_COMPRESS u8"\uf066"
#define ICON_FA_COMPRESS_ALT u8"\uf422"
#define ICON_FA_COMPRESS_ARROWS_ALT u8"\uf78c"
#define ICON_FA_COMPRESS_WIDE u8"\uf326"
#define ICON_FA_COMPUTER_CLASSIC u8"\uf8b1"
#define ICON_FA_COMPUTER_SPEAKER u8"\uf8b2"
#define ICON_FA_CONCIERGE_BELL u8"\uf562"
#define ICON_FA_CONSTRUCTION u8"\uf85d"
#define ICON_FA_CONTAINER_STORAGE u8"\uf4b7"
#define ICON_FA_CONVEYOR_BELT u8"\uf46e"
#define ICON_FA_CONVEYOR_BELT_ALT u8"\uf46f"
#define ICON_FA_COOKIE u8"\uf563"
#define ICON_FA_COOKIE_BITE u8"\uf564"
#define ICON_FA_COPY u8"\uf0c5"
#define ICON_FA_COPYRIGHT u8"\uf1f9"
#define ICON_FA_CORN u8"\uf6c7"
#define ICON_FA_COUCH u8"\uf4b8"
#define ICON_FA_COW u8"\uf6c8"
#define ICON_FA_COWBELL u8"\uf8b3"
#define ICON_FA_COWBELL_MORE u8"\uf8b4"
#define ICON_FA_CREDIT_CARD u8"\uf09d"
#define ICON_FA_CREDIT_CARD_BLANK u8"\uf389"
#define ICON_FA_CREDIT_CARD_FRONT u8"\uf38a"
#define ICON_FA_CRICKET u8"\uf449"
#define ICON_FA_CROISSANT u8"\uf7f6"
#define ICON_FA_CROP u8"\uf125"
#define ICON_FA_CROP_ALT u8"\uf565"
#define ICON_FA_CROSS u8"\uf654"
#define ICON_FA_CROSSHAIRS u8"\uf05b"
#define ICON_FA_CROW u8"\uf520"
#define ICON_FA_CROWN u8"\uf521"
#define ICON_FA_CRUTCH u8"\uf7f7"
#define ICON_FA_CRUTCHES u8"\uf7f8"
#define ICON_FA_CUBE u8"\uf1b2"
#define ICON_FA_CUBES u8"\uf1b3"
#define ICON_FA_CURLING u8"\uf44a"
#define ICON_FA_CUT u8"\uf0c4"
#define ICON_FA_DAGGER u8"\uf6cb"
#define ICON_FA_DATABASE u8"\uf1c0"
#define ICON_FA_DEAF u8"\uf2a4"
#define ICON_FA_DEBUG u8"\uf7f9"
#define ICON_FA_DEER u8"\uf78e"
#define ICON_FA_DEER_RUDOLPH u8"\uf78f"
#define ICON_FA_DEMOCRAT u8"\uf747"
#define ICON_FA_DESKTOP u8"\uf108"
#define ICON_FA_DESKTOP_ALT u8"\uf390"
#define ICON_FA_DEWPOINT u8"\uf748"
#define ICON_FA_DHARMACHAKRA u8"\uf655"
#define ICON_FA_DIAGNOSES u8"\uf470"
#define ICON_FA_DIAMOND u8"\uf219"
#define ICON_FA_DICE u8"\uf522"
#define ICON_FA_DICE_D10 u8"\uf6cd"
#define ICON_FA_DICE_D12 u8"\uf6ce"
#define ICON_FA_DICE_D20 u8"\uf6cf"
#define ICON_FA_DICE_D4 u8"\uf6d0"
#define ICON_FA_DICE_D6 u8"\uf6d1"
#define ICON_FA_DICE_D8 u8"\uf6d2"
#define ICON_FA_DICE_FIVE u8"\uf523"
#define ICON_FA_DICE_FOUR u8"\uf524"
#define ICON_FA_DICE_ONE u8"\uf525"
#define ICON_FA_DICE_SIX u8"\uf526"
#define ICON_FA_DICE_THREE u8"\uf527"
#define ICON_FA_DICE_TWO u8"\uf528"
#define ICON_FA_DIGGING u8"\uf85e"
#define ICON_FA_DIGITAL_TACHOGRAPH u8"\uf566"
#define ICON_FA_DIPLOMA u8"\uf5ea"
#define ICON_FA_DIRECTIONS u8"\uf5eb"
#define ICON_FA_DISC_DRIVE u8"\uf8b5"
#define ICON_FA_DISEASE u8"\uf7fa"
#define ICON_FA_DIVIDE u8"\uf529"
#define ICON_FA_DIZZY u8"\uf567"
#define ICON_FA_DNA u8"\uf471"
#define ICON_FA_DO_NOT_ENTER u8"\uf5ec"
#define ICON_FA_DOG u8"\uf6d3"
#define ICON_FA_DOG_LEASHED u8"\uf6d4"
#define ICON_FA_DOLLAR_SIGN u8"\uf155"
#define ICON_FA_DOLLY u8"\uf472"
#define ICON_FA_DOLLY_EMPTY u8"\uf473"
#define ICON_FA_DOLLY_FLATBED u8"\uf474"
#define ICON_FA_DOLLY_FLATBED_ALT u8"\uf475"
#define ICON_FA_DOLLY_FLATBED_EMPTY u8"\uf476"
#define ICON_FA_DONATE u8"\uf4b9"
#define ICON_FA_DOOR_CLOSED u8"\uf52a"
#define ICON_FA_DOOR_OPEN u8"\uf52b"
#define ICON_FA_DOT_CIRCLE u8"\uf192"
#define ICON_FA_DOVE u8"\uf4ba"
#define ICON_FA_DOWNLOAD u8"\uf019"
#define ICON_FA_DRAFTING_COMPASS u8"\uf568"
#define ICON_FA_DRAGON u8"\uf6d5"
#define ICON_FA_DRAW_CIRCLE u8"\uf5ed"
#define ICON_FA_DRAW_POLYGON u8"\uf5ee"
#define ICON_FA_DRAW_SQUARE u8"\uf5ef"
#define ICON_FA_DREIDEL u8"\uf792"
#define ICON_FA_DRONE u8"\uf85f"
#define ICON_FA_DRONE_ALT u8"\uf860"
#define ICON_FA_DRUM u8"\uf569"
#define ICON_FA_DRUM_STEELPAN u8"\uf56a"
#define ICON_FA_DRUMSTICK u8"\uf6d6"
#define ICON_FA_DRUMSTICK_BITE u8"\uf6d7"
#define ICON_FA_DRYER u8"\uf861"
#define ICON_FA_DRYER_ALT u8"\uf862"
#define ICON_FA_DUCK u8"\uf6d8"
#define ICON_FA_DUMBBELL u8"\uf44b"
#define ICON_FA_DUMPSTER u8"\uf793"
#define ICON_FA_DUMPSTER_FIRE u8"\uf794"
#define ICON_FA_DUNGEON u8"\uf6d9"
#define ICON_FA_EAR u8"\uf5f0"
#define ICON_FA_EAR_MUFFS u8"\uf795"
#define ICON_FA_ECLIPSE u8"\uf749"
#define ICON_FA_ECLIPSE_ALT u8"\uf74a"
#define ICON_FA_EDIT u8"\uf044"
#define ICON_FA_EGG u8"\uf7fb"
#define ICON_FA_EGG_FRIED u8"\uf7fc"
#define ICON_FA_EJECT u8"\uf052"
#define ICON_FA_ELEPHANT u8"\uf6da"
#define ICON_FA_ELLIPSIS_H u8"\uf141"
#define ICON_FA_ELLIPSIS_H_ALT u8"\uf39b"
#define ICON_FA_ELLIPSIS_V u8"\uf142"
#define ICON_FA_ELLIPSIS_V_ALT u8"\uf39c"
#define ICON_FA_EMPTY_SET u8"\uf656"
#define ICON_FA_ENGINE_WARNING u8"\uf5f2"
#define ICON_FA_ENVELOPE u8"\uf0e0"
#define ICON_FA_ENVELOPE_OPEN u8"\uf2b6"
#define ICON_FA_ENVELOPE_OPEN_DOLLAR u8"\uf657"
#define ICON_FA_ENVELOPE_OPEN_TEXT u8"\uf658"
#define ICON_FA_ENVELOPE_SQUARE u8"\uf199"
#define ICON_FA_EQUALS u8"\uf52c"
#define ICON_FA_ERASER u8"\uf12d"
#define ICON_FA_ETHERNET u8"\uf796"
#define ICON_FA_EURO_SIGN u8"\uf153"
#define ICON_FA_EXCHANGE u8"\uf0ec"
#define ICON_FA_EXCHANGE_ALT u8"\uf362"
#define ICON_FA_EXCLAMATION u8"\uf12a"
#define ICON_FA_EXCLAMATION_CIRCLE u8"\uf06a"
#define ICON_FA_EXCLAMATION_SQUARE u8"\uf321"
#define ICON_FA_EXCLAMATION_TRIANGLE u8"\uf071"
#define ICON_FA_EXPAND u8"\uf065"
#define ICON_FA_EXPAND_ALT u8"\uf424"
#define ICON_FA_EXPAND_ARROWS u8"\uf31d"
#define ICON_FA_EXPAND_ARROWS_ALT u8"\uf31e"
#define ICON_FA_EXPAND_WIDE u8"\uf320"
#define ICON_FA_EXTERNAL_LINK u8"\uf08e"
#define ICON_FA_EXTERNAL_LINK_ALT u8"\uf35d"
#define ICON_FA_EXTERNAL_LINK_SQUARE u8"\uf14c"
#define ICON_FA_EXTERNAL_LINK_SQUARE_ALT u8"\uf360"
#define ICON_FA_EYE u8"\uf06e"
#define ICON_FA_EYE_DROPPER u8"\uf1fb"
#define ICON_FA_EYE_EVIL u8"\uf6db"
#define ICON_FA_EYE_SLASH u8"\uf070"
#define ICON_FA_FAN u8"\uf863"
#define ICON_FA_FAN_TABLE u8"\ue004"
#define ICON_FA_FARM u8"\uf864"
#define ICON_FA_FAST_BACKWARD u8"\uf049"
#define ICON_FA_FAST_FORWARD u8"\uf050"
#define ICON_FA_FAUCET u8"\ue005"
#define ICON_FA_FAUCET_DRIP u8"\ue006"
#define ICON_FA_FAX u8"\uf1ac"
#define ICON_FA_FEATHER u8"\uf52d"
#define ICON_FA_FEATHER_ALT u8"\uf56b"
#define ICON_FA_FEMALE u8"\uf182"
#define ICON_FA_FIELD_HOCKEY u8"\uf44c"
#define ICON_FA_FIGHTER_JET u8"\uf0fb"
#define ICON_FA_FILE u8"\uf15b"
#define ICON_FA_FILE_ALT u8"\uf15c"
#define ICON_FA_FILE_ARCHIVE u8"\uf1c6"
#define ICON_FA_FILE_AUDIO u8"\uf1c7"
#define ICON_FA_FILE_CERTIFICATE u8"\uf5f3"
#define ICON_FA_FILE_CHART_LINE u8"\uf659"
#define ICON_FA_FILE_CHART_PIE u8"\uf65a"
#define ICON_FA_FILE_CHECK u8"\uf316"
#define ICON_FA_FILE_CODE u8"\uf1c9"
#define ICON_FA_FILE_CONTRACT u8"\uf56c"
#define ICON_FA_FILE_CSV u8"\uf6dd"
#define ICON_FA_FILE_DOWNLOAD u8"\uf56d"
#define ICON_FA_FILE_EDIT u8"\uf31c"
#define ICON_FA_FILE_EXCEL u8"\uf1c3"
#define ICON_FA_FILE_EXCLAMATION u8"\uf31a"
#define ICON_FA_FILE_EXPORT u8"\uf56e"
#define ICON_FA_FILE_IMAGE u8"\uf1c5"
#define ICON_FA_FILE_IMPORT u8"\uf56f"
#define ICON_FA_FILE_INVOICE u8"\uf570"
#define ICON_FA_FILE_INVOICE_DOLLAR u8"\uf571"
#define ICON_FA_FILE_MEDICAL u8"\uf477"
#define ICON_FA_FILE_MEDICAL_ALT u8"\uf478"
#define ICON_FA_FILE_MINUS u8"\uf318"
#define ICON_FA_FILE_MUSIC u8"\uf8b6"
#define ICON_FA_FILE_PDF u8"\uf1c1"
#define ICON_FA_FILE_PLUS u8"\uf319"
#define ICON_FA_FILE_POWERPOINT u8"\uf1c4"
#define ICON_FA_FILE_PRESCRIPTION u8"\uf572"
#define ICON_FA_FILE_SEARCH u8"\uf865"
#define ICON_FA_FILE_SIGNATURE u8"\uf573"
#define ICON_FA_FILE_SPREADSHEET u8"\uf65b"
#define ICON_FA_FILE_TIMES u8"\uf317"
#define ICON_FA_FILE_UPLOAD u8"\uf574"
#define ICON_FA_FILE_USER u8"\uf65c"
#define ICON_FA_FILE_VIDEO u8"\uf1c8"
#define ICON_FA_FILE_WORD u8"\uf1c2"
#define ICON_FA_FILES_MEDICAL u8"\uf7fd"
#define ICON_FA_FILL u8"\uf575"
#define ICON_FA_FILL_DRIP u8"\uf576"
#define ICON_FA_FILM u8"\uf008"
#define ICON_FA_FILM_ALT u8"\uf3a0"
#define ICON_FA_FILM_CANISTER u8"\uf8b7"
#define ICON_FA_FILTER u8"\uf0b0"
#define ICON_FA_FINGERPRINT u8"\uf577"
#define ICON_FA_FIRE u8"\uf06d"
#define ICON_FA_FIRE_ALT u8"\uf7e4"
#define ICON_FA_FIRE_EXTINGUISHER u8"\uf134"
#define ICON_FA_FIRE_SMOKE u8"\uf74b"
#define ICON_FA_FIREPLACE u8"\uf79a"
#define ICON_FA_FIRST_AID u8"\uf479"
#define ICON_FA_FISH u8"\uf578"
#define ICON_FA_FISH_COOKED u8"\uf7fe"
#define ICON_FA_FIST_RAISED u8"\uf6de"
#define ICON_FA_FLAG u8"\uf024"
#define ICON_FA_FLAG_ALT u8"\uf74c"
#define ICON_FA_FLAG_CHECKERED u8"\uf11e"
#define ICON_FA_FLAG_USA u8"\uf74d"
#define ICON_FA_FLAME u8"\uf6df"
#define ICON_FA_FLASHLIGHT u8"\uf8b8"
#define ICON_FA_FLASK u8"\uf0c3"
#define ICON_FA_FLASK_POISON u8"\uf6e0"
#define ICON_FA_FLASK_POTION u8"\uf6e1"
#define ICON_FA_FLOWER u8"\uf7ff"
#define ICON_FA_FLOWER_DAFFODIL u8"\uf800"
#define ICON_FA_FLOWER_TULIP u8"\uf801"
#define ICON_FA_FLUSHED u8"\uf579"
#define ICON_FA_FLUTE u8"\uf8b9"
#define ICON_FA_FLUX_CAPACITOR u8"\uf8ba"
#define ICON_FA_FOG u8"\uf74e"
#define ICON_FA_FOLDER u8"\uf07b"
#define ICON_FA_FOLDER_DOWNLOAD u8"\ue053"
#define ICON_FA_FOLDER_MINUS u8"\uf65d"
#define ICON_FA_FOLDER_OPEN u8"\uf07c"
#define ICON_FA_FOLDER_PLUS u8"\uf65e"
#define ICON_FA_FOLDER_TIMES u8"\uf65f"
#define ICON_FA_FOLDER_TREE u8"\uf802"
#define ICON_FA_FOLDER_UPLOAD u8"\ue054"
#define ICON_FA_FOLDERS u8"\uf660"
#define ICON_FA_FONT u8"\uf031"
#define ICON_FA_FONT_AWESOME_LOGO_FULL u8"\uf4e6"
#define ICON_FA_FONT_CASE u8"\uf866"
#define ICON_FA_FOOTBALL_BALL u8"\uf44e"
#define ICON_FA_FOOTBALL_HELMET u8"\uf44f"
#define ICON_FA_FORKLIFT u8"\uf47a"
#define ICON_FA_FORWARD u8"\uf04e"
#define ICON_FA_FRAGILE u8"\uf4bb"
#define ICON_FA_FRENCH_FRIES u8"\uf803"
#define ICON_FA_FROG u8"\uf52e"
#define ICON_FA_FROSTY_HEAD u8"\uf79b"
#define ICON_FA_FROWN u8"\uf119"
#define ICON_FA_FROWN_OPEN u8"\uf57a"
#define ICON_FA_FUNCTION u8"\uf661"
#define ICON_FA_FUNNEL_DOLLAR u8"\uf662"
#define ICON_FA_FUTBOL u8"\uf1e3"
#define ICON_FA_GALAXY u8"\ue008"
#define ICON_FA_GAME_BOARD u8"\uf867"
#define ICON_FA_GAME_BOARD_ALT u8"\uf868"
#define ICON_FA_GAME_CONSOLE_HANDHELD u8"\uf8bb"
#define ICON_FA_GAMEPAD u8"\uf11b"
#define ICON_FA_GAMEPAD_ALT u8"\uf8bc"
#define ICON_FA_GARAGE u8"\ue009"
#define ICON_FA_GARAGE_CAR u8"\ue00a"
#define ICON_FA_GARAGE_OPEN u8"\ue00b"
#define ICON_FA_GAS_PUMP u8"\uf52f"
#define ICON_FA_GAS_PUMP_SLASH u8"\uf5f4"
#define ICON_FA_GAVEL u8"\uf0e3"
#define ICON_FA_GEM u8"\uf3a5"
#define ICON_FA_GENDERLESS u8"\uf22d"
#define ICON_FA_GHOST u8"\uf6e2"
#define ICON_FA_GIFT u8"\uf06b"
#define ICON_FA_GIFT_CARD u8"\uf663"
#define ICON_FA_GIFTS u8"\uf79c"
#define ICON_FA_GINGERBREAD_MAN u8"\uf79d"
#define ICON_FA_GLASS u8"\uf804"
#define ICON_FA_GLASS_CHAMPAGNE u8"\uf79e"
#define ICON_FA_GLASS_CHEERS u8"\uf79f"
#define ICON_FA_GLASS_CITRUS u8"\uf869"
#define ICON_FA_GLASS_MARTINI u8"\uf000"
#define ICON_FA_GLASS_MARTINI_ALT u8"\uf57b"
#define ICON_FA_GLASS_WHISKEY u8"\uf7a0"
#define ICON_FA_GLASS_WHISKEY_ROCKS u8"\uf7a1"
#define ICON_FA_GLASSES u8"\uf530"
#define ICON_FA_GLASSES_ALT u8"\uf5f5"
#define ICON_FA_GLOBE u8"\uf0ac"
#define ICON_FA_GLOBE_AFRICA u8"\uf57c"
#define ICON_FA_GLOBE_AMERICAS u8"\uf57d"
#define ICON_FA_GLOBE_ASIA u8"\uf57e"
#define ICON_FA_GLOBE_EUROPE u8"\uf7a2"
#define ICON_FA_GLOBE_SNOW u8"\uf7a3"
#define ICON_FA_GLOBE_STAND u8"\uf5f6"
#define ICON_FA_GOLF_BALL u8"\uf450"
#define ICON_FA_GOLF_CLUB u8"\uf451"
#define ICON_FA_GOPURAM u8"\uf664"
#define ICON_FA_GRADUATION_CAP u8"\uf19d"
#define ICON_FA_GRAMOPHONE u8"\uf8bd"
#define ICON_FA_GREATER_THAN u8"\uf531"
#define ICON_FA_GREATER_THAN_EQUAL u8"\uf532"
#define ICON_FA_GRIMACE u8"\uf57f"
#define ICON_FA_GRIN u8"\uf580"
#define ICON_FA_GRIN_ALT u8"\uf581"
#define ICON_FA_GRIN_BEAM u8"\uf582"
#define ICON_FA_GRIN_BEAM_SWEAT u8"\uf583"
#define ICON_FA_GRIN_HEARTS u8"\uf584"
#define ICON_FA_GRIN_SQUINT u8"\uf585"
#define ICON_FA_GRIN_SQUINT_TEARS u8"\uf586"
#define ICON_FA_GRIN_STARS u8"\uf587"
#define ICON_FA_GRIN_TEARS u8"\uf588"
#define ICON_FA_GRIN_TONGUE u8"\uf589"
#define ICON_FA_GRIN_TONGUE_SQUINT u8"\uf58a"
#define ICON_FA_GRIN_TONGUE_WINK u8"\uf58b"
#define ICON_FA_GRIN_WINK u8"\uf58c"
#define ICON_FA_GRIP_HORIZONTAL u8"\uf58d"
#define ICON_FA_GRIP_LINES u8"\uf7a4"
#define ICON_FA_GRIP_LINES_VERTICAL u8"\uf7a5"
#define ICON_FA_GRIP_VERTICAL u8"\uf58e"
#define ICON_FA_GUITAR u8"\uf7a6"
#define ICON_FA_GUITAR_ELECTRIC u8"\uf8be"
#define ICON_FA_GUITARS u8"\uf8bf"
#define ICON_FA_H_SQUARE u8"\uf0fd"
#define ICON_FA_H1 u8"\uf313"
#define ICON_FA_H2 u8"\uf314"
#define ICON_FA_H3 u8"\uf315"
#define ICON_FA_H4 u8"\uf86a"
#define ICON_FA_HAMBURGER u8"\uf805"
#define ICON_FA_HAMMER u8"\uf6e3"
#define ICON_FA_HAMMER_WAR u8"\uf6e4"
#define ICON_FA_HAMSA u8"\uf665"
#define ICON_FA_HAND_HEART u8"\uf4bc"
#define ICON_FA_HAND_HOLDING u8"\uf4bd"
#define ICON_FA_HAND_HOLDING_BOX u8"\uf47b"
#define ICON_FA_HAND_HOLDING_HEART u8"\uf4be"
#define ICON_FA_HAND_HOLDING_MAGIC u8"\uf6e5"
#define ICON_FA_HAND_HOLDING_MEDICAL u8"\ue05c"
#define ICON_FA_HAND_HOLDING_SEEDLING u8"\uf4bf"
#define ICON_FA_HAND_HOLDING_USD u8"\uf4c0"
#define ICON_FA_HAND_HOLDING_WATER u8"\uf4c1"
#define ICON_FA_HAND_LIZARD u8"\uf258"
#define ICON_FA_HAND_MIDDLE_FINGER u8"\uf806"
#define ICON_FA_HAND_PAPER u8"\uf256"
#define ICON_FA_HAND_PEACE u8"\uf25b"
#define ICON_FA_HAND_POINT_DOWN u8"\uf0a7"
#define ICON_FA_HAND_POINT_LEFT u8"\uf0a5"
#define ICON_FA_HAND_POINT_RIGHT u8"\uf0a4"
#define ICON_FA_HAND_POINT_UP u8"\uf0a6"
#define ICON_FA_HAND_POINTER u8"\uf25a"
#define ICON_FA_HAND_RECEIVING u8"\uf47c"
#define ICON_FA_HAND_ROCK u8"\uf255"
#define ICON_FA_HAND_SCISSORS u8"\uf257"
#define ICON_FA_HAND_SPARKLES u8"\ue05d"
#define ICON_FA_HAND_SPOCK u8"\uf259"
#define ICON_FA_HANDS u8"\uf4c2"
#define ICON_FA_HANDS_HEART u8"\uf4c3"
#define ICON_FA_HANDS_HELPING u8"\uf4c4"
#define ICON_FA_HANDS_USD u8"\uf4c5"
#define ICON_FA_HANDS_WASH u8"\ue05e"
#define ICON_FA_HANDSHAKE u8"\uf2b5"
#define ICON_FA_HANDSHAKE_ALT u8"\uf4c6"
#define ICON_FA_HANDSHAKE_ALT_SLASH u8"\ue05f"
#define ICON_FA_HANDSHAKE_SLASH u8"\ue060"
#define ICON_FA_HANUKIAH u8"\uf6e6"
#define ICON_FA_HARD_HAT u8"\uf807"
#define ICON_FA_HASHTAG u8"\uf292"
#define ICON_FA_HAT_CHEF u8"\uf86b"
#define ICON_FA_HAT_COWBOY u8"\uf8c0"
#define ICON_FA_HAT_COWBOY_SIDE u8"\uf8c1"
#define ICON_FA_HAT_SANTA u8"\uf7a7"
#define ICON_FA_HAT_WINTER u8"\uf7a8"
#define ICON_FA_HAT_WITCH u8"\uf6e7"
#define ICON_FA_HAT_WIZARD u8"\uf6e8"
#define ICON_FA_HDD u8"\uf0a0"
#define ICON_FA_HEAD_SIDE u8"\uf6e9"
#define ICON_FA_HEAD_SIDE_BRAIN u8"\uf808"
#define ICON_FA_HEAD_SIDE_COUGH u8"\ue061"
#define ICON_FA_HEAD_SIDE_COUGH_SLASH u8"\ue062"
#define ICON_FA_HEAD_SIDE_HEADPHONES u8"\uf8c2"
#define ICON_FA_HEAD_SIDE_MASK u8"\ue063"
#define ICON_FA_HEAD_SIDE_MEDICAL u8"\uf809"
#define ICON_FA_HEAD_SIDE_VIRUS u8"\ue064"
#define ICON_FA_HEAD_VR u8"\uf6ea"
#define ICON_FA_HEADING u8"\uf1dc"
#define ICON_FA_HEADPHONES u8"\uf025"
#define ICON_FA_HEADPHONES_ALT u8"\uf58f"
#define ICON_FA_HEADSET u8"\uf590"
#define ICON_FA_HEART u8"\uf004"
#define ICON_FA_HEART_BROKEN u8"\uf7a9"
#define ICON_FA_HEART_CIRCLE u8"\uf4c7"
#define ICON_FA_HEART_RATE u8"\uf5f8"
#define ICON_FA_HEART_SQUARE u8"\uf4c8"
#define ICON_FA_HEARTBEAT u8"\uf21e"
#define ICON_FA_HEAT u8"\ue00c"
#define ICON_FA_HELICOPTER u8"\uf533"
#define ICON_FA_HELMET_BATTLE u8"\uf6eb"
#define ICON_FA_HEXAGON u8"\uf312"
#define ICON_FA_HIGHLIGHTER u8"\uf591"
#define ICON_FA_HIKING u8"\uf6ec"
#define ICON_FA_HIPPO u8"\uf6ed"
#define ICON_FA_HISTORY u8"\uf1da"
#define ICON_FA_HOCKEY_MASK u8"\uf6ee"
#define ICON_FA_HOCKEY_PUCK u8"\uf453"
#define ICON_FA_HOCKEY_STICKS u8"\uf454"
#define ICON_FA_HOLLY_BERRY u8"\uf7aa"
#define ICON_FA_HOME u8"\uf015"
#define ICON_FA_HOME_ALT u8"\uf80a"
#define ICON_FA_HOME_HEART u8"\uf4c9"
#define ICON_FA_HOME_LG u8"\uf80b"
#define ICON_FA_HOME_LG_ALT u8"\uf80c"
#define ICON_FA_HOOD_CLOAK u8"\uf6ef"
#define ICON_FA_HORIZONTAL_RULE u8"\uf86c"
#define ICON_FA_HORSE u8"\uf6f0"
#define ICON_FA_HORSE_HEAD u8"\uf7ab"
#define ICON_FA_HORSE_SADDLE u8"\uf8c3"
#define ICON_FA_HOSPITAL u8"\uf0f8"
#define ICON_FA_HOSPITAL_ALT u8"\uf47d"
#define ICON_FA_HOSPITAL_SYMBOL u8"\uf47e"
#define ICON_FA_HOSPITAL_USER u8"\uf80d"
#define ICON_FA_HOSPITALS u8"\uf80e"
#define ICON_FA_HOT_TUB u8"\uf593"
#define ICON_FA_HOTDOG u8"\uf80f"
#define ICON_FA_HOTEL u8"\uf594"
#define ICON_FA_HOURGLASS u8"\uf254"
#define ICON_FA_HOURGLASS_END u8"\uf253"
#define ICON_FA_HOURGLASS_HALF u8"\uf252"
#define ICON_FA_HOURGLASS_START u8"\uf251"
#define ICON_FA_HOUSE u8"\ue00d"
#define ICON_FA_HOUSE_DAMAGE u8"\uf6f1"
#define ICON_FA_HOUSE_DAY u8"\ue00e"
#define ICON_FA_HOUSE_FLOOD u8"\uf74f"
#define ICON_FA_HOUSE_LEAVE u8"\ue00f"
#define ICON_FA_HOUSE_NIGHT u8"\ue010"
#define ICON_FA_HOUSE_RETURN u8"\ue011"
#define ICON_FA_HOUSE_SIGNAL u8"\ue012"
#define ICON_FA_HOUSE_USER u8"\ue065"
#define ICON_FA_HRYVNIA u8"\uf6f2"
#define ICON_FA_HUMIDITY u8"\uf750"
#define ICON_FA_HURRICANE u8"\uf751"
#define ICON_FA_I_CURSOR u8"\uf246"
#define ICON_FA_ICE_CREAM u8"\uf810"
#define ICON_FA_ICE_SKATE u8"\uf7ac"
#define ICON_FA_ICICLES u8"\uf7ad"
#define ICON_FA_ICONS u8"\uf86d"
#define ICON_FA_ICONS_ALT u8"\uf86e"
#define ICON_FA_ID_BADGE u8"\uf2c1"
#define ICON_FA_ID_CARD u8"\uf2c2"
#define ICON_FA_ID_CARD_ALT u8"\uf47f"
#define ICON_FA_IGLOO u8"\uf7ae"
#define ICON_FA_IMAGE u8"\uf03e"
#define ICON_FA_IMAGE_POLAROID u8"\uf8c4"
#define ICON_FA_IMAGES u8"\uf302"
#define ICON_FA_INBOX u8"\uf01c"
#define ICON_FA_INBOX_IN u8"\uf310"
#define ICON_FA_INBOX_OUT u8"\uf311"
#define ICON_FA_INDENT u8"\uf03c"
#define ICON_FA_INDUSTRY u8"\uf275"
#define ICON_FA_INDUSTRY_ALT u8"\uf3b3"
#define ICON_FA_INFINITY u8"\uf534"
#define ICON_FA_INFO u8"\uf129"
#define ICON_FA_INFO_CIRCLE u8"\uf05a"
#define ICON_FA_INFO_SQUARE u8"\uf30f"
#define ICON_FA_INHALER u8"\uf5f9"
#define ICON_FA_INTEGRAL u8"\uf667"
#define ICON_FA_INTERSECTION u8"\uf668"
#define ICON_FA_INVENTORY u8"\uf480"
#define ICON_FA_ISLAND_TROPICAL u8"\uf811"
#define ICON_FA_ITALIC u8"\uf033"
#define ICON_FA_JACK_O_LANTERN u8"\uf30e"
#define ICON_FA_JEDI u8"\uf669"
#define ICON_FA_JOINT u8"\uf595"
#define ICON_FA_JOURNAL_WHILLS u8"\uf66a"
#define ICON_FA_JOYSTICK u8"\uf8c5"
#define ICON_FA_JUG u8"\uf8c6"
#define ICON_FA_KAABA u8"\uf66b"
#define ICON_FA_KAZOO u8"\uf8c7"
#define ICON_FA_KERNING u8"\uf86f"
#define ICON_FA_KEY u8"\uf084"
#define ICON_FA_KEY_SKELETON u8"\uf6f3"
#define ICON_FA_KEYBOARD u8"\uf11c"
#define ICON_FA_KEYNOTE u8"\uf66c"
#define ICON_FA_KHANDA u8"\uf66d"
#define ICON_FA_KIDNEYS u8"\uf5fb"
#define ICON_FA_KISS u8"\uf596"
#define ICON_FA_KISS_BEAM u8"\uf597"
#define ICON_FA_KISS_WINK_HEART u8"\uf598"
#define ICON_FA_KITE u8"\uf6f4"
#define ICON_FA_KIWI_BIRD u8"\uf535"
#define ICON_FA_KNIFE_KITCHEN u8"\uf6f5"
#define ICON_FA_LAMBDA u8"\uf66e"
#define ICON_FA_LAMP u8"\uf4ca"
#define ICON_FA_LAMP_DESK u8"\ue014"
#define ICON_FA_LAMP_FLOOR u8"\ue015"
#define ICON_FA_LANDMARK u8"\uf66f"
#define ICON_FA_LANDMARK_ALT u8"\uf752"
#define ICON_FA_LANGUAGE u8"\uf1ab"
#define ICON_FA_LAPTOP u8"\uf109"
#define ICON_FA_LAPTOP_CODE u8"\uf5fc"
#define ICON_FA_LAPTOP_HOUSE u8"\ue066"
#define ICON_FA_LAPTOP_MEDICAL u8"\uf812"
#define ICON_FA_LASSO u8"\uf8c8"
#define ICON_FA_LAUGH u8"\uf599"
#define ICON_FA_LAUGH_BEAM u8"\uf59a"
#define ICON_FA_LAUGH_SQUINT u8"\uf59b"
#define ICON_FA_LAUGH_WINK u8"\uf59c"
#define ICON_FA_LAYER_GROUP u8"\uf5fd"
#define ICON_FA_LAYER_MINUS u8"\uf5fe"
#define ICON_FA_LAYER_PLUS u8"\uf5ff"
#define ICON_FA_LEAF u8"\uf06c"
#define ICON_FA_LEAF_HEART u8"\uf4cb"
#define ICON_FA_LEAF_MAPLE u8"\uf6f6"
#define ICON_FA_LEAF_OAK u8"\uf6f7"
#define ICON_FA_LEMON u8"\uf094"
#define ICON_FA_LESS_THAN u8"\uf536"
#define ICON_FA_LESS_THAN_EQUAL u8"\uf537"
#define ICON_FA_LEVEL_DOWN u8"\uf149"
#define ICON_FA_LEVEL_DOWN_ALT u8"\uf3be"
#define ICON_FA_LEVEL_UP u8"\uf148"
#define ICON_FA_LEVEL_UP_ALT u8"\uf3bf"
#define ICON_FA_LIFE_RING u8"\uf1cd"
#define ICON_FA_LIGHT_CEILING u8"\ue016"
#define ICON_FA_LIGHT_SWITCH u8"\ue017"
#define ICON_FA_LIGHT_SWITCH_OFF u8"\ue018"
#define ICON_FA_LIGHT_SWITCH_ON u8"\ue019"
#define ICON_FA_LIGHTBULB u8"\uf0eb"
#define ICON_FA_LIGHTBULB_DOLLAR u8"\uf670"
#define ICON_FA_LIGHTBULB_EXCLAMATION u8"\uf671"
#define ICON_FA_LIGHTBULB_ON u8"\uf672"
#define ICON_FA_LIGHTBULB_SLASH u8"\uf673"
#define ICON_FA_LIGHTS_HOLIDAY u8"\uf7b2"
#define ICON_FA_LINE_COLUMNS u8"\uf870"
#define ICON_FA_LINE_HEIGHT u8"\uf871"
#define ICON_FA_LINK u8"\uf0c1"
#define ICON_FA_LIPS u8"\uf600"
#define ICON_FA_LIRA_SIGN u8"\uf195"
#define ICON_FA_LIST u8"\uf03a"
#define ICON_FA_LIST_ALT u8"\uf022"
#define ICON_FA_LIST_MUSIC u8"\uf8c9"
#define ICON_FA_LIST_OL u8"\uf0cb"
#define ICON_FA_LIST_UL u8"\uf0ca"
#define ICON_FA_LOCATION u8"\uf601"
#define ICON_FA_LOCATION_ARROW u8"\uf124"
#define ICON_FA_LOCATION_CIRCLE u8"\uf602"
#define ICON_FA_LOCATION_SLASH u8"\uf603"
#define ICON_FA_LOCK u8"\uf023"
#define ICON_FA_LOCK_ALT u8"\uf30d"
#define ICON_FA_LOCK_OPEN u8"\uf3c1"
#define ICON_FA_LOCK_OPEN_ALT u8"\uf3c2"
#define ICON_FA_LONG_ARROW_ALT_DOWN u8"\uf309"
#define ICON_FA_LONG_ARROW_ALT_LEFT u8"\uf30a"
#define ICON_FA_LONG_ARROW_ALT_RIGHT u8"\uf30b"
#define ICON_FA_LONG_ARROW_ALT_UP u8"\uf30c"
#define ICON_FA_LONG_ARROW_DOWN u8"\uf175"
#define ICON_FA_LONG_ARROW_LEFT u8"\uf177"
#define ICON_FA_LONG_ARROW_RIGHT u8"\uf178"
#define ICON_FA_LONG_ARROW_UP u8"\uf176"
#define ICON_FA_LOVESEAT u8"\uf4cc"
#define ICON_FA_LOW_VISION u8"\uf2a8"
#define ICON_FA_LUCHADOR u8"\uf455"
#define ICON_FA_LUGGAGE_CART u8"\uf59d"
#define ICON_FA_LUNGS u8"\uf604"
#define ICON_FA_LUNGS_VIRUS u8"\ue067"
#define ICON_FA_MACE u8"\uf6f8"
#define ICON_FA_MAGIC u8"\uf0d0"
#define ICON_FA_MAGNET u8"\uf076"
#define ICON_FA_MAIL_BULK u8"\uf674"
#define ICON_FA_MAILBOX u8"\uf813"
#define ICON_FA_MALE u8"\uf183"
#define ICON_FA_MANDOLIN u8"\uf6f9"
#define ICON_FA_MAP u8"\uf279"
#define ICON_FA_MAP_MARKED u8"\uf59f"
#define ICON_FA_MAP_MARKED_ALT u8"\uf5a0"
#define ICON_FA_MAP_MARKER u8"\uf041"
#define ICON_FA_MAP_MARKER_ALT u8"\uf3c5"
#define ICON_FA_MAP_MARKER_ALT_SLASH u8"\uf605"
#define ICON_FA_MAP_MARKER_CHECK u8"\uf606"
#define ICON_FA_MAP_MARKER_EDIT u8"\uf607"
#define ICON_FA_MAP_MARKER_EXCLAMATION u8"\uf608"
#define ICON_FA_MAP_MARKER_MINUS u8"\uf609"
#define ICON_FA_MAP_MARKER_PLUS u8"\uf60a"
#define ICON_FA_MAP_MARKER_QUESTION u8"\uf60b"
#define ICON_FA_MAP_MARKER_SLASH u8"\uf60c"
#define ICON_FA_MAP_MARKER_SMILE u8"\uf60d"
#define ICON_FA_MAP_MARKER_TIMES u8"\uf60e"
#define ICON_FA_MAP_PIN u8"\uf276"
#define ICON_FA_MAP_SIGNS u8"\uf277"
#define ICON_FA_MARKER u8"\uf5a1"
#define ICON_FA_MARS u8"\uf222"
#define ICON_FA_MARS_DOUBLE u8"\uf227"
#define ICON_FA_MARS_STROKE u8"\uf229"
#define ICON_FA_MARS_STROKE_H u8"\uf22b"
#define ICON_FA_MARS_STROKE_V u8"\uf22a"
#define ICON_FA_MASK u8"\uf6fa"
#define ICON_FA_MEAT u8"\uf814"
#define ICON_FA_MEDAL u8"\uf5a2"
#define ICON_FA_MEDKIT u8"\uf0fa"
#define ICON_FA_MEGAPHONE u8"\uf675"
#define ICON_FA_MEH u8"\uf11a"
#define ICON_FA_MEH_BLANK u8"\uf5a4"
#define ICON_FA_MEH_ROLLING_EYES u8"\uf5a5"
#define ICON_FA_MEMORY u8"\uf538"
#define ICON_FA_MENORAH u8"\uf676"
#define ICON_FA_MERCURY u8"\uf223"
#define ICON_FA_METEOR u8"\uf753"
#define ICON_FA_MICROCHIP u8"\uf2db"
#define ICON_FA_MICROPHONE u8"\uf130"
#define ICON_FA_MICROPHONE_ALT u8"\uf3c9"
#define ICON_FA_MICROPHONE_ALT_SLASH u8"\uf539"
#define ICON_FA_MICROPHONE_SLASH u8"\uf131"
#define ICON_FA_MICROPHONE_STAND u8"\uf8cb"
#define ICON_FA_MICROSCOPE u8"\uf610"
#define ICON_FA_MICROWAVE u8"\ue01b"
#define ICON_FA_MIND_SHARE u8"\uf677"
#define ICON_FA_MINUS u8"\uf068"
#define ICON_FA_MINUS_CIRCLE u8"\uf056"
#define ICON_FA_MINUS_HEXAGON u8"\uf307"
#define ICON_FA_MINUS_OCTAGON u8"\uf308"
#define ICON_FA_MINUS_SQUARE u8"\uf146"
#define ICON_FA_MISTLETOE u8"\uf7b4"
#define ICON_FA_MITTEN u8"\uf7b5"
#define ICON_FA_MOBILE u8"\uf10b"
#define ICON_FA_MOBILE_ALT u8"\uf3cd"
#define ICON_FA_MOBILE_ANDROID u8"\uf3ce"
#define ICON_FA_MOBILE_ANDROID_ALT u8"\uf3cf"
#define ICON_FA_MONEY_BILL u8"\uf0d6"
#define ICON_FA_MONEY_BILL_ALT u8"\uf3d1"
#define ICON_FA_MONEY_BILL_WAVE u8"\uf53a"
#define ICON_FA_MONEY_BILL_WAVE_ALT u8"\uf53b"
#define ICON_FA_MONEY_CHECK u8"\uf53c"
#define ICON_FA_MONEY_CHECK_ALT u8"\uf53d"
#define ICON_FA_MONEY_CHECK_EDIT u8"\uf872"
#define ICON_FA_MONEY_CHECK_EDIT_ALT u8"\uf873"
#define ICON_FA_MONITOR_HEART_RATE u8"\uf611"
#define ICON_FA_MONKEY u8"\uf6fb"
#define ICON_FA_MONUMENT u8"\uf5a6"
#define ICON_FA_MOON u8"\uf186"
#define ICON_FA_MOON_CLOUD u8"\uf754"
#define ICON_FA_MOON_STARS u8"\uf755"
#define ICON_FA_MORTAR_PESTLE u8"\uf5a7"
#define ICON_FA_MOSQUE u8"\uf678"
#define ICON_FA_MOTORCYCLE u8"\uf21c"
#define ICON_FA_MOUNTAIN u8"\uf6fc"
#define ICON_FA_MOUNTAINS u8"\uf6fd"
#define ICON_FA_MOUSE u8"\uf8cc"
#define ICON_FA_MOUSE_ALT u8"\uf8cd"
#define ICON_FA_MOUSE_POINTER u8"\uf245"
#define ICON_FA_MP3_PLAYER u8"\uf8ce"
#define ICON_FA_MUG u8"\uf874"
#define ICON_FA_MUG_HOT u8"\uf7b6"
#define ICON_FA_MUG_MARSHMALLOWS u8"\uf7b7"
#define ICON_FA_MUG_TEA u8"\uf875"
#define ICON_FA_MUSIC u8"\uf001"
#define ICON_FA_MUSIC_ALT u8"\uf8cf"
#define ICON_FA_MUSIC_ALT_SLASH u8"\uf8d0"
#define ICON_FA_MUSIC_SLASH u8"\uf8d1"
#define ICON_FA_NARWHAL u8"\uf6fe"
#define ICON_FA_NETWORK_WIRED u8"\uf6ff"
#define ICON_FA_NEUTER u8"\uf22c"
#define ICON_FA_NEWSPAPER u8"\uf1ea"
#define ICON_FA_NOT_EQUAL u8"\uf53e"
#define ICON_FA_NOTES_MEDICAL u8"\uf481"
#define ICON_FA_OBJECT_GROUP u8"\uf247"
#define ICON_FA_OBJECT_UNGROUP u8"\uf248"
#define ICON_FA_OCTAGON u8"\uf306"
#define ICON_FA_OIL_CAN u8"\uf613"
#define ICON_FA_OIL_TEMP u8"\uf614"
#define ICON_FA_OM u8"\uf679"
#define ICON_FA_OMEGA u8"\uf67a"
#define ICON_FA_ORNAMENT u8"\uf7b8"
#define ICON_FA_OTTER u8"\uf700"
#define ICON_FA_OUTDENT u8"\uf03b"
#define ICON_FA_OUTLET u8"\ue01c"
#define ICON_FA_OVEN u8"\ue01d"
#define ICON_FA_OVERLINE u8"\uf876"
#define ICON_FA_PAGE_BREAK u8"\uf877"
#define ICON_FA_PAGER u8"\uf815"
#define ICON_FA_PAINT_BRUSH u8"\uf1fc"
#define ICON_FA_PAINT_BRUSH_ALT u8"\uf5a9"
#define ICON_FA_PAINT_ROLLER u8"\uf5aa"
#define ICON_FA_PALETTE u8"\uf53f"
#define ICON_FA_PALLET u8"\uf482"
#define ICON_FA_PALLET_ALT u8"\uf483"
#define ICON_FA_PAPER_PLANE u8"\uf1d8"
#define ICON_FA_PAPERCLIP u8"\uf0c6"
#define ICON_FA_PARACHUTE_BOX u8"\uf4cd"
#define ICON_FA_PARAGRAPH u8"\uf1dd"
#define ICON_FA_PARAGRAPH_RTL u8"\uf878"
#define ICON_FA_PARKING u8"\uf540"
#define ICON_FA_PARKING_CIRCLE u8"\uf615"
#define ICON_FA_PARKING_CIRCLE_SLASH u8"\uf616"
#define ICON_FA_PARKING_SLASH u8"\uf617"
#define ICON_FA_PASSPORT u8"\uf5ab"
#define ICON_FA_PASTAFARIANISM u8"\uf67b"
#define ICON_FA_PASTE u8"\uf0ea"
#define ICON_FA_PAUSE u8"\uf04c"
#define ICON_FA_PAUSE_CIRCLE u8"\uf28b"
#define ICON_FA_PAW u8"\uf1b0"
#define ICON_FA_PAW_ALT u8"\uf701"
#define ICON_FA_PAW_CLAWS u8"\uf702"
#define ICON_FA_PEACE u8"\uf67c"
#define ICON_FA_PEGASUS u8"\uf703"
#define ICON_FA_PEN u8"\uf304"
#define ICON_FA_PEN_ALT u8"\uf305"
#define ICON_FA_PEN_FANCY u8"\uf5ac"
#define ICON_FA_PEN_NIB u8"\uf5ad"
#define ICON_FA_PEN_SQUARE u8"\uf14b"
#define ICON_FA_PENCIL u8"\uf040"
#define ICON_FA_PENCIL_ALT u8"\uf303"
#define ICON_FA_PENCIL_PAINTBRUSH u8"\uf618"
#define ICON_FA_PENCIL_RULER u8"\uf5ae"
#define ICON_FA_PENNANT u8"\uf456"
#define ICON_FA_PEOPLE_ARROWS u8"\ue068"
#define ICON_FA_PEOPLE_CARRY u8"\uf4ce"
#define ICON_FA_PEPPER_HOT u8"\uf816"
#define ICON_FA_PERCENT u8"\uf295"
#define ICON_FA_PERCENTAGE u8"\uf541"
#define ICON_FA_PERSON_BOOTH u8"\uf756"
#define ICON_FA_PERSON_CARRY u8"\uf4cf"
#define ICON_FA_PERSON_DOLLY u8"\uf4d0"
#define ICON_FA_PERSON_DOLLY_EMPTY u8"\uf4d1"
#define ICON_FA_PERSON_SIGN u8"\uf757"
#define ICON_FA_PHONE u8"\uf095"
#define ICON_FA_PHONE_ALT u8"\uf879"
#define ICON_FA_PHONE_LAPTOP u8"\uf87a"
#define ICON_FA_PHONE_OFFICE u8"\uf67d"
#define ICON_FA_PHONE_PLUS u8"\uf4d2"
#define ICON_FA_PHONE_ROTARY u8"\uf8d3"
#define ICON_FA_PHONE_SLASH u8"\uf3dd"
#define ICON_FA_PHONE_SQUARE u8"\uf098"
#define ICON_FA_PHONE_SQUARE_ALT u8"\uf87b"
#define ICON_FA_PHONE_VOLUME u8"\uf2a0"
#define ICON_FA_PHOTO_VIDEO u8"\uf87c"
#define ICON_FA_PI u8"\uf67e"
#define ICON_FA_PIANO u8"\uf8d4"
#define ICON_FA_PIANO_KEYBOARD u8"\uf8d5"
#define ICON_FA_PIE u8"\uf705"
#define ICON_FA_PIG u8"\uf706"
#define ICON_FA_PIGGY_BANK u8"\uf4d3"
#define ICON_FA_PILLS u8"\uf484"
#define ICON_FA_PIZZA u8"\uf817"
#define ICON_FA_PIZZA_SLICE u8"\uf818"
#define ICON_FA_PLACE_OF_WORSHIP u8"\uf67f"
#define ICON_FA_PLANE u8"\uf072"
#define ICON_FA_PLANE_ALT u8"\uf3de"
#define ICON_FA_PLANE_ARRIVAL u8"\uf5af"
#define ICON_FA_PLANE_DEPARTURE u8"\uf5b0"
#define ICON_FA_PLANE_SLASH u8"\ue069"
#define ICON_FA_PLANET_MOON u8"\ue01f"
#define ICON_FA_PLANET_RINGED u8"\ue020"
#define ICON_FA_PLAY u8"\uf04b"
#define ICON_FA_PLAY_CIRCLE u8"\uf144"
#define ICON_FA_PLUG u8"\uf1e6"
#define ICON_FA_PLUS u8"\uf067"
#define ICON_FA_PLUS_CIRCLE u8"\uf055"
#define ICON_FA_PLUS_HEXAGON u8"\uf300"
#define ICON_FA_PLUS_OCTAGON u8"\uf301"
#define ICON_FA_PLUS_SQUARE u8"\uf0fe"
#define ICON_FA_PODCAST u8"\uf2ce"
#define ICON_FA_PODIUM u8"\uf680"
#define ICON_FA_PODIUM_STAR u8"\uf758"
#define ICON_FA_POLICE_BOX u8"\ue021"
#define ICON_FA_POLL u8"\uf681"
#define ICON_FA_POLL_H u8"\uf682"
#define ICON_FA_POLL_PEOPLE u8"\uf759"
#define ICON_FA_POO u8"\uf2fe"
#define ICON_FA_POO_STORM u8"\uf75a"
#define ICON_FA_POOP u8"\uf619"
#define ICON_FA_POPCORN u8"\uf819"
#define ICON_FA_PORTAL_ENTER u8"\ue022"
#define ICON_FA_PORTAL_EXIT u8"\ue023"
#define ICON_FA_PORTRAIT u8"\uf3e0"
#define ICON_FA_POUND_SIGN u8"\uf154"
#define ICON_FA_POWER_OFF u8"\uf011"
#define ICON_FA_PRAY u8"\uf683"
#define ICON_FA_PRAYING_HANDS u8"\uf684"
#define ICON_FA_PRESCRIPTION u8"\uf5b1"
#define ICON_FA_PRESCRIPTION_BOTTLE u8"\uf485"
#define ICON_FA_PRESCRIPTION_BOTTLE_ALT u8"\uf486"
#define ICON_FA_PRESENTATION u8"\uf685"
#define ICON_FA_PRINT u8"\uf02f"
#define ICON_FA_PRINT_SEARCH u8"\uf81a"
#define ICON_FA_PRINT_SLASH u8"\uf686"
#define ICON_FA_PROCEDURES u8"\uf487"
#define ICON_FA_PROJECT_DIAGRAM u8"\uf542"
#define ICON_FA_PROJECTOR u8"\uf8d6"
#define ICON_FA_PUMP_MEDICAL u8"\ue06a"
#define ICON_FA_PUMP_SOAP u8"\ue06b"
#define ICON_FA_PUMPKIN u8"\uf707"
#define ICON_FA_PUZZLE_PIECE u8"\uf12e"
#define ICON_FA_QRCODE u8"\uf029"
#define ICON_FA_QUESTION u8"\uf128"
#define ICON_FA_QUESTION_CIRCLE u8"\uf059"
#define ICON_FA_QUESTION_SQUARE u8"\uf2fd"
#define ICON_FA_QUIDDITCH u8"\uf458"
#define ICON_FA_QUOTE_LEFT u8"\uf10d"
#define ICON_FA_QUOTE_RIGHT u8"\uf10e"
#define ICON_FA_QURAN u8"\uf687"
#define ICON_FA_RABBIT u8"\uf708"
#define ICON_FA_RABBIT_FAST u8"\uf709"
#define ICON_FA_RACQUET u8"\uf45a"
#define ICON_FA_RADAR u8"\ue024"
#define ICON_FA_RADIATION u8"\uf7b9"
#define ICON_FA_RADIATION_ALT u8"\uf7ba"
#define ICON_FA_RADIO u8"\uf8d7"
#define ICON_FA_RADIO_ALT u8"\uf8d8"
#define ICON_FA_RAINBOW u8"\uf75b"
#define ICON_FA_RAINDROPS u8"\uf75c"
#define ICON_FA_RAM u8"\uf70a"
#define ICON_FA_RAMP_LOADING u8"\uf4d4"
#define ICON_FA_RANDOM u8"\uf074"
#define ICON_FA_RAYGUN u8"\ue025"
#define ICON_FA_RECEIPT u8"\uf543"
#define ICON_FA_RECORD_VINYL u8"\uf8d9"
#define ICON_FA_RECTANGLE_LANDSCAPE u8"\uf2fa"
#define ICON_FA_RECTANGLE_PORTRAIT u8"\uf2fb"
#define ICON_FA_RECTANGLE_WIDE u8"\uf2fc"
#define ICON_FA_RECYCLE u8"\uf1b8"
#define ICON_FA_REDO u8"\uf01e"
#define ICON_FA_REDO_ALT u8"\uf2f9"
#define ICON_FA_REFRIGERATOR u8"\ue026"
#define ICON_FA_REGISTERED u8"\uf25d"
#define ICON_FA_REMOVE_FORMAT u8"\uf87d"
#define ICON_FA_REPEAT u8"\uf363"
#define ICON_FA_REPEAT_1 u8"\uf365"
#define ICON_FA_REPEAT_1_ALT u8"\uf366"
#define ICON_FA_REPEAT_ALT u8"\uf364"
#define ICON_FA_REPLY u8"\uf3e5"
#define ICON_FA_REPLY_ALL u8"\uf122"
#define ICON_FA_REPUBLICAN u8"\uf75e"
#define ICON_FA_RESTROOM u8"\uf7bd"
#define ICON_FA_RETWEET u8"\uf079"
#define ICON_FA_RETWEET_ALT u8"\uf361"
#define ICON_FA_RIBBON u8"\uf4d6"
#define ICON_FA_RING u8"\uf70b"
#define ICON_FA_RINGS_WEDDING u8"\uf81b"
#define ICON_FA_ROAD u8"\uf018"
#define ICON_FA_ROBOT u8"\uf544"
#define ICON_FA_ROCKET u8"\uf135"
#define ICON_FA_ROCKET_LAUNCH u8"\ue027"
#define ICON_FA_ROUTE u8"\uf4d7"
#define ICON_FA_ROUTE_HIGHWAY u8"\uf61a"
#define ICON_FA_ROUTE_INTERSTATE u8"\uf61b"
#define ICON_FA_ROUTER u8"\uf8da"
#define ICON_FA_RSS u8"\uf09e"
#define ICON_FA_RSS_SQUARE u8"\uf143"
#define ICON_FA_RUBLE_SIGN u8"\uf158"
#define ICON_FA_RULER u8"\uf545"
#define ICON_FA_RULER_COMBINED u8"\uf546"
#define ICON_FA_RULER_HORIZONTAL u8"\uf547"
#define ICON_FA_RULER_TRIANGLE u8"\uf61c"
#define ICON_FA_RULER_VERTICAL u8"\uf548"
#define ICON_FA_RUNNING u8"\uf70c"
#define ICON_FA_RUPEE_SIGN u8"\uf156"
#define ICON_FA_RV u8"\uf7be"
#define ICON_FA_SACK u8"\uf81c"
#define ICON_FA_SACK_DOLLAR u8"\uf81d"
#define ICON_FA_SAD_CRY u8"\uf5b3"
#define ICON_FA_SAD_TEAR u8"\uf5b4"
#define ICON_FA_SALAD u8"\uf81e"
#define ICON_FA_SANDWICH u8"\uf81f"
#define ICON_FA_SATELLITE u8"\uf7bf"
#define ICON_FA_SATELLITE_DISH u8"\uf7c0"
#define ICON_FA_SAUSAGE u8"\uf820"
#define ICON_FA_SAVE u8"\uf0c7"
#define ICON_FA_SAX_HOT u8"\uf8db"
#define ICON_FA_SAXOPHONE u8"\uf8dc"
#define ICON_FA_SCALPEL u8"\uf61d"
#define ICON_FA_SCALPEL_PATH u8"\uf61e"
#define ICON_FA_SCANNER u8"\uf488"
#define ICON_FA_SCANNER_IMAGE u8"\uf8f3"
#define ICON_FA_SCANNER_KEYBOARD u8"\uf489"
#define ICON_FA_SCANNER_TOUCHSCREEN u8"\uf48a"
#define ICON_FA_SCARECROW u8"\uf70d"
#define ICON_FA_SCARF u8"\uf7c1"
#define ICON_FA_SCHOOL u8"\uf549"
#define ICON_FA_SCREWDRIVER u8"\uf54a"
#define ICON_FA_SCROLL u8"\uf70e"
#define ICON_FA_SCROLL_OLD u8"\uf70f"
#define ICON_FA_SCRUBBER u8"\uf2f8"
#define ICON_FA_SCYTHE u8"\uf710"
#define ICON_FA_SD_CARD u8"\uf7c2"
#define ICON_FA_SEARCH u8"\uf002"
#define ICON_FA_SEARCH_DOLLAR u8"\uf688"
#define ICON_FA_SEARCH_LOCATION u8"\uf689"
#define ICON_FA_SEARCH_MINUS u8"\uf010"
#define ICON_FA_SEARCH_PLUS u8"\uf00e"
#define ICON_FA_SEEDLING u8"\uf4d8"
#define ICON_FA_SEND_BACK u8"\uf87e"
#define ICON_FA_SEND_BACKWARD u8"\uf87f"
#define ICON_FA_SENSOR u8"\ue028"
#define ICON_FA_SENSOR_ALERT u8"\ue029"
#define ICON_FA_SENSOR_FIRE u8"\ue02a"
#define ICON_FA_SENSOR_ON u8"\ue02b"
#define ICON_FA_SENSOR_SMOKE u8"\ue02c"
#define ICON_FA_SERVER u8"\uf233"
#define ICON_FA_SHAPES u8"\uf61f"
#define ICON_FA_SHARE u8"\uf064"
#define ICON_FA_SHARE_ALL u8"\uf367"
#define ICON_FA_SHARE_ALT u8"\uf1e0"
#define ICON_FA_SHARE_ALT_SQUARE u8"\uf1e1"
#define ICON_FA_SHARE_SQUARE u8"\uf14d"
#define ICON_FA_SHEEP u8"\uf711"
#define ICON_FA_SHEKEL_SIGN u8"\uf20b"
#define ICON_FA_SHIELD u8"\uf132"
#define ICON_FA_SHIELD_ALT u8"\uf3ed"
#define ICON_FA_SHIELD_CHECK u8"\uf2f7"
#define ICON_FA_SHIELD_CROSS u8"\uf712"
#define ICON_FA_SHIELD_VIRUS u8"\ue06c"
#define ICON_FA_SHIP u8"\uf21a"
#define ICON_FA_SHIPPING_FAST u8"\uf48b"
#define ICON_FA_SHIPPING_TIMED u8"\uf48c"
#define ICON_FA_SHISH_KEBAB u8"\uf821"
#define ICON_FA_SHOE_PRINTS u8"\uf54b"
#define ICON_FA_SHOPPING_BAG u8"\uf290"
#define ICON_FA_SHOPPING_BASKET u8"\uf291"
#define ICON_FA_SHOPPING_CART u8"\uf07a"
#define ICON_FA_SHOVEL u8"\uf713"
#define ICON_FA_SHOVEL_SNOW u8"\uf7c3"
#define ICON_FA_SHOWER u8"\uf2cc"
#define ICON_FA_SHREDDER u8"\uf68a"
#define ICON_FA_SHUTTLE_VAN u8"\uf5b6"
#define ICON_FA_SHUTTLECOCK u8"\uf45b"
#define ICON_FA_SICKLE u8"\uf822"
#define ICON_FA_SIGMA u8"\uf68b"
#define ICON_FA_SIGN u8"\uf4d9"
#define ICON_FA_SIGN_IN u8"\uf090"
#define ICON_FA_SIGN_IN_ALT u8"\uf2f6"
#define ICON_FA_SIGN_LANGUAGE u8"\uf2a7"
#define ICON_FA_SIGN_OUT u8"\uf08b"
#define ICON_FA_SIGN_OUT_ALT u8"\uf2f5"
#define ICON_FA_SIGNAL u8"\uf012"
#define ICON_FA_SIGNAL_1 u8"\uf68c"
#define ICON_FA_SIGNAL_2 u8"\uf68d"
#define ICON_FA_SIGNAL_3 u8"\uf68e"
#define ICON_FA_SIGNAL_4 u8"\uf68f"
#define ICON_FA_SIGNAL_ALT u8"\uf690"
#define ICON_FA_SIGNAL_ALT_1 u8"\uf691"
#define ICON_FA_SIGNAL_ALT_2 u8"\uf692"
#define ICON_FA_SIGNAL_ALT_3 u8"\uf693"
#define ICON_FA_SIGNAL_ALT_SLASH u8"\uf694"
#define ICON_FA_SIGNAL_SLASH u8"\uf695"
#define ICON_FA_SIGNAL_STREAM u8"\uf8dd"
#define ICON_FA_SIGNATURE u8"\uf5b7"
#define ICON_FA_SIM_CARD u8"\uf7c4"
#define ICON_FA_SINK u8"\ue06d"
#define ICON_FA_SIREN u8"\ue02d"
#define ICON_FA_SIREN_ON u8"\ue02e"
#define ICON_FA_SITEMAP u8"\uf0e8"
#define ICON_FA_SKATING u8"\uf7c5"
#define ICON_FA_SKELETON u8"\uf620"
#define ICON_FA_SKI_JUMP u8"\uf7c7"
#define ICON_FA_SKI_LIFT u8"\uf7c8"
#define ICON_FA_SKIING u8"\uf7c9"
#define ICON_FA_SKIING_NORDIC u8"\uf7ca"
#define ICON_FA_SKULL u8"\uf54c"
#define ICON_FA_SKULL_COW u8"\uf8de"
#define ICON_FA_SKULL_CROSSBONES u8"\uf714"
#define ICON_FA_SLASH u8"\uf715"
#define ICON_FA_SLEDDING u8"\uf7cb"
#define ICON_FA_SLEIGH u8"\uf7cc"
#define ICON_FA_SLIDERS_H u8"\uf1de"
#define ICON_FA_SLIDERS_H_SQUARE u8"\uf3f0"
#define ICON_FA_SLIDERS_V u8"\uf3f1"
#define ICON_FA_SLIDERS_V_SQUARE u8"\uf3f2"
#define ICON_FA_SMILE u8"\uf118"
#define ICON_FA_SMILE_BEAM u8"\uf5b8"
#define ICON_FA_SMILE_PLUS u8"\uf5b9"
#define ICON_FA_SMILE_WINK u8"\uf4da"
#define ICON_FA_SMOG u8"\uf75f"
#define ICON_FA_SMOKE u8"\uf760"
#define ICON_FA_SMOKING u8"\uf48d"
#define ICON_FA_SMOKING_BAN u8"\uf54d"
#define ICON_FA_SMS u8"\uf7cd"
#define ICON_FA_SNAKE u8"\uf716"
#define ICON_FA_SNOOZE u8"\uf880"
#define ICON_FA_SNOW_BLOWING u8"\uf761"
#define ICON_FA_SNOWBOARDING u8"\uf7ce"
#define ICON_FA_SNOWFLAKE u8"\uf2dc"
#define ICON_FA_SNOWFLAKES u8"\uf7cf"
#define ICON_FA_SNOWMAN u8"\uf7d0"
#define ICON_FA_SNOWMOBILE u8"\uf7d1"
#define ICON_FA_SNOWPLOW u8"\uf7d2"
#define ICON_FA_SOAP u8"\ue06e"
#define ICON_FA_SOCKS u8"\uf696"
#define ICON_FA_SOLAR_PANEL u8"\uf5ba"
#define ICON_FA_SOLAR_SYSTEM u8"\ue02f"
#define ICON_FA_SORT u8"\uf0dc"
#define ICON_FA_SORT_ALPHA_DOWN u8"\uf15d"
#define ICON_FA_SORT_ALPHA_DOWN_ALT u8"\uf881"
#define ICON_FA_SORT_ALPHA_UP u8"\uf15e"
#define ICON_FA_SORT_ALPHA_UP_ALT u8"\uf882"
#define ICON_FA_SORT_ALT u8"\uf883"
#define ICON_FA_SORT_AMOUNT_DOWN u8"\uf160"
#define ICON_FA_SORT_AMOUNT_DOWN_ALT u8"\uf884"
#define ICON_FA_SORT_AMOUNT_UP u8"\uf161"
#define ICON_FA_SORT_AMOUNT_UP_ALT u8"\uf885"
#define ICON_FA_SORT_CIRCLE u8"\ue030"
#define ICON_FA_SORT_CIRCLE_DOWN u8"\ue031"
#define ICON_FA_SORT_CIRCLE_UP u8"\ue032"
#define ICON_FA_SORT_DOWN u8"\uf0dd"
#define ICON_FA_SORT_NUMERIC_DOWN u8"\uf162"
#define ICON_FA_SORT_NUMERIC_DOWN_ALT u8"\uf886"
#define ICON_FA_SORT_NUMERIC_UP u8"\uf163"
#define ICON_FA_SORT_NUMERIC_UP_ALT u8"\uf887"
#define ICON_FA_SORT_SHAPES_DOWN u8"\uf888"
#define ICON_FA_SORT_SHAPES_DOWN_ALT u8"\uf889"
#define ICON_FA_SORT_SHAPES_UP u8"\uf88a"
#define ICON_FA_SORT_SHAPES_UP_ALT u8"\uf88b"
#define ICON_FA_SORT_SIZE_DOWN u8"\uf88c"
#define ICON_FA_SORT_SIZE_DOWN_ALT u8"\uf88d"
#define ICON_FA_SORT_SIZE_UP u8"\uf88e"
#define ICON_FA_SORT_SIZE_UP_ALT u8"\uf88f"
#define ICON_FA_SORT_UP u8"\uf0de"
#define ICON_FA_SOUP u8"\uf823"
#define ICON_FA_SPA u8"\uf5bb"
#define ICON_FA_SPACE_SHUTTLE u8"\uf197"
#define ICON_FA_SPACE_STATION_MOON u8"\ue033"
#define ICON_FA_SPACE_STATION_MOON_ALT u8"\ue034"
#define ICON_FA_SPADE u8"\uf2f4"
#define ICON_FA_SPARKLES u8"\uf890"
#define ICON_FA_SPEAKER u8"\uf8df"
#define ICON_FA_SPEAKERS u8"\uf8e0"
#define ICON_FA_SPELL_CHECK u8"\uf891"
#define ICON_FA_SPIDER u8"\uf717"
#define ICON_FA_SPIDER_BLACK_WIDOW u8"\uf718"
#define ICON_FA_SPIDER_WEB u8"\uf719"
#define ICON_FA_SPINNER u8"\uf110"
#define ICON_FA_SPINNER_THIRD u8"\uf3f4"
#define ICON_FA_SPLOTCH u8"\uf5bc"
#define ICON_FA_SPRAY_CAN u8"\uf5bd"
#define ICON_FA_SPRINKLER u8"\ue035"
#define ICON_FA_SQUARE u8"\uf0c8"
#define ICON_FA_SQUARE_FULL u8"\uf45c"
#define ICON_FA_SQUARE_ROOT u8"\uf697"
#define ICON_FA_SQUARE_ROOT_ALT u8"\uf698"
#define ICON_FA_SQUIRREL u8"\uf71a"
#define ICON_FA_STAFF u8"\uf71b"
#define ICON_FA_STAMP u8"\uf5bf"
#define ICON_FA_STAR u8"\uf005"
#define ICON_FA_STAR_AND_CRESCENT u8"\uf699"
#define ICON_FA_STAR_CHRISTMAS u8"\uf7d4"
#define ICON_FA_STAR_EXCLAMATION u8"\uf2f3"
#define ICON_FA_STAR_HALF u8"\uf089"
#define ICON_FA_STAR_HALF_ALT u8"\uf5c0"
#define ICON_FA_STAR_OF_DAVID u8"\uf69a"
#define ICON_FA_STAR_OF_LIFE u8"\uf621"
#define ICON_FA_STAR_SHOOTING u8"\ue036"
#define ICON_FA_STARFIGHTER u8"\ue037"
#define ICON_FA_STARFIGHTER_ALT u8"\ue038"
#define ICON_FA_STARS u8"\uf762"
#define ICON_FA_STARSHIP u8"\ue039"
#define ICON_FA_STARSHIP_FREIGHTER u8"\ue03a"
#define ICON_FA_STEAK u8"\uf824"
#define ICON_FA_STEERING_WHEEL u8"\uf622"
#define ICON_FA_STEP_BACKWARD u8"\uf048"
#define ICON_FA_STEP_FORWARD u8"\uf051"
#define ICON_FA_STETHOSCOPE u8"\uf0f1"
#define ICON_FA_STICKY_NOTE u8"\uf249"
#define ICON_FA_STOCKING u8"\uf7d5"
#define ICON_FA_STOMACH u8"\uf623"
#define ICON_FA_STOP u8"\uf04d"
#define ICON_FA_STOP_CIRCLE u8"\uf28d"
#define ICON_FA_STOPWATCH u8"\uf2f2"
#define ICON_FA_STOPWATCH_20 u8"\ue06f"
#define ICON_FA_STORE u8"\uf54e"
#define ICON_FA_STORE_ALT u8"\uf54f"
#define ICON_FA_STORE_ALT_SLASH u8"\ue070"
#define ICON_FA_STORE_SLASH u8"\ue071"
#define ICON_FA_STREAM u8"\uf550"
#define ICON_FA_STREET_VIEW u8"\uf21d"
#define ICON_FA_STRETCHER u8"\uf825"
#define ICON_FA_STRIKETHROUGH u8"\uf0cc"
#define ICON_FA_STROOPWAFEL u8"\uf551"
#define ICON_FA_SUBSCRIPT u8"\uf12c"
#define ICON_FA_SUBWAY u8"\uf239"
#define ICON_FA_SUITCASE u8"\uf0f2"
#define ICON_FA_SUITCASE_ROLLING u8"\uf5c1"
#define ICON_FA_SUN u8"\uf185"
#define ICON_FA_SUN_CLOUD u8"\uf763"
#define ICON_FA_SUN_DUST u8"\uf764"
#define ICON_FA_SUN_HAZE u8"\uf765"
#define ICON_FA_SUNGLASSES u8"\uf892"
#define ICON_FA_SUNRISE u8"\uf766"
#define ICON_FA_SUNSET u8"\uf767"
#define ICON_FA_SUPERSCRIPT u8"\uf12b"
#define ICON_FA_SURPRISE u8"\uf5c2"
#define ICON_FA_SWATCHBOOK u8"\uf5c3"
#define ICON_FA_SWIMMER u8"\uf5c4"
#define ICON_FA_SWIMMING_POOL u8"\uf5c5"
#define ICON_FA_SWORD u8"\uf71c"
#define ICON_FA_SWORD_LASER u8"\ue03b"
#define ICON_FA_SWORD_LASER_ALT u8"\ue03c"
#define ICON_FA_SWORDS u8"\uf71d"
#define ICON_FA_SWORDS_LASER u8"\ue03d"
#define ICON_FA_SYNAGOGUE u8"\uf69b"
#define ICON_FA_SYNC u8"\uf021"
#define ICON_FA_SYNC_ALT u8"\uf2f1"
#define ICON_FA_SYRINGE u8"\uf48e"
#define ICON_FA_TABLE u8"\uf0ce"
#define ICON_FA_TABLE_TENNIS u8"\uf45d"
#define ICON_FA_TABLET u8"\uf10a"
#define ICON_FA_TABLET_ALT u8"\uf3fa"
#define ICON_FA_TABLET_ANDROID u8"\uf3fb"
#define ICON_FA_TABLET_ANDROID_ALT u8"\uf3fc"
#define ICON_FA_TABLET_RUGGED u8"\uf48f"
#define ICON_FA_TABLETS u8"\uf490"
#define ICON_FA_TACHOMETER u8"\uf0e4"
#define ICON_FA_TACHOMETER_ALT u8"\uf3fd"
#define ICON_FA_TACHOMETER_ALT_AVERAGE u8"\uf624"
#define ICON_FA_TACHOMETER_ALT_FAST u8"\uf625"
#define ICON_FA_TACHOMETER_ALT_FASTEST u8"\uf626"
#define ICON_FA_TACHOMETER_ALT_SLOW u8"\uf627"
#define ICON_FA_TACHOMETER_ALT_SLOWEST u8"\uf628"
#define ICON_FA_TACHOMETER_AVERAGE u8"\uf629"
#define ICON_FA_TACHOMETER_FAST u8"\uf62a"
#define ICON_FA_TACHOMETER_FASTEST u8"\uf62b"
#define ICON_FA_TACHOMETER_SLOW u8"\uf62c"
#define ICON_FA_TACHOMETER_SLOWEST u8"\uf62d"
#define ICON_FA_TACO u8"\uf826"
#define ICON_FA_TAG u8"\uf02b"
#define ICON_FA_TAGS u8"\uf02c"
#define ICON_FA_TALLY u8"\uf69c"
#define ICON_FA_TANAKH u8"\uf827"
#define ICON_FA_TAPE u8"\uf4db"
#define ICON_FA_TASKS u8"\uf0ae"
#define ICON_FA_TASKS_ALT u8"\uf828"
#define ICON_FA_TAXI u8"\uf1ba"
#define ICON_FA_TEETH u8"\uf62e"
#define ICON_FA_TEETH_OPEN u8"\uf62f"
#define ICON_FA_TELESCOPE u8"\ue03e"
#define ICON_FA_TEMPERATURE_DOWN u8"\ue03f"
#define ICON_FA_TEMPERATURE_FRIGID u8"\uf768"
#define ICON_FA_TEMPERATURE_HIGH u8"\uf769"
#define ICON_FA_TEMPERATURE_HOT u8"\uf76a"
#define ICON_FA_TEMPERATURE_LOW u8"\uf76b"
#define ICON_FA_TEMPERATURE_UP u8"\ue040"
#define ICON_FA_TENGE u8"\uf7d7"
#define ICON_FA_TENNIS_BALL u8"\uf45e"
#define ICON_FA_TERMINAL u8"\uf120"
#define ICON_FA_TEXT u8"\uf893"
#define ICON_FA_TEXT_HEIGHT u8"\uf034"
#define ICON_FA_TEXT_SIZE u8"\uf894"
#define ICON_FA_TEXT_WIDTH u8"\uf035"
#define ICON_FA_TH u8"\uf00a"
#define ICON_FA_TH_LARGE u8"\uf009"
#define ICON_FA_TH_LIST u8"\uf00b"
#define ICON_FA_THEATER_MASKS u8"\uf630"
#define ICON_FA_THERMOMETER u8"\uf491"
#define ICON_FA_THERMOMETER_EMPTY u8"\uf2cb"
#define ICON_FA_THERMOMETER_FULL u8"\uf2c7"
#define ICON_FA_THERMOMETER_HALF u8"\uf2c9"
#define ICON_FA_THERMOMETER_QUARTER u8"\uf2ca"
#define ICON_FA_THERMOMETER_THREE_QUARTERS u8"\uf2c8"
#define ICON_FA_THETA u8"\uf69e"
#define ICON_FA_THUMBS_DOWN u8"\uf165"
#define ICON_FA_THUMBS_UP u8"\uf164"
#define ICON_FA_THUMBTACK u8"\uf08d"
#define ICON_FA_THUNDERSTORM u8"\uf76c"
#define ICON_FA_THUNDERSTORM_MOON u8"\uf76d"
#define ICON_FA_THUNDERSTORM_SUN u8"\uf76e"
#define ICON_FA_TICKET u8"\uf145"
#define ICON_FA_TICKET_ALT u8"\uf3ff"
#define ICON_FA_TILDE u8"\uf69f"
#define ICON_FA_TIMES u8"\uf00d"
#define ICON_FA_TIMES_CIRCLE u8"\uf057"
#define ICON_FA_TIMES_HEXAGON u8"\uf2ee"
#define ICON_FA_TIMES_OCTAGON u8"\uf2f0"
#define ICON_FA_TIMES_SQUARE u8"\uf2d3"
#define ICON_FA_TINT u8"\uf043"
#define ICON_FA_TINT_SLASH u8"\uf5c7"
#define ICON_FA_TIRE u8"\uf631"
#define ICON_FA_TIRE_FLAT u8"\uf632"
#define ICON_FA_TIRE_PRESSURE_WARNING u8"\uf633"
#define ICON_FA_TIRE_RUGGED u8"\uf634"
#define ICON_FA_TIRED u8"\uf5c8"
#define ICON_FA_TOGGLE_OFF u8"\uf204"
#define ICON_FA_TOGGLE_ON u8"\uf205"
#define ICON_FA_TOILET u8"\uf7d8"
#define ICON_FA_TOILET_PAPER u8"\uf71e"
#define ICON_FA_TOILET_PAPER_ALT u8"\uf71f"
#define ICON_FA_TOILET_PAPER_SLASH u8"\ue072"
#define ICON_FA_TOMBSTONE u8"\uf720"
#define ICON_FA_TOMBSTONE_ALT u8"\uf721"
#define ICON_FA_TOOLBOX u8"\uf552"
#define ICON_FA_TOOLS u8"\uf7d9"
#define ICON_FA_TOOTH u8"\uf5c9"
#define ICON_FA_TOOTHBRUSH u8"\uf635"
#define ICON_FA_TORAH u8"\uf6a0"
#define ICON_FA_TORII_GATE u8"\uf6a1"
#define ICON_FA_TORNADO u8"\uf76f"
#define ICON_FA_TRACTOR u8"\uf722"
#define ICON_FA_TRADEMARK u8"\uf25c"
#define ICON_FA_TRAFFIC_CONE u8"\uf636"
#define ICON_FA_TRAFFIC_LIGHT u8"\uf637"
#define ICON_FA_TRAFFIC_LIGHT_GO u8"\uf638"
#define ICON_FA_TRAFFIC_LIGHT_SLOW u8"\uf639"
#define ICON_FA_TRAFFIC_LIGHT_STOP u8"\uf63a"
#define ICON_FA_TRAILER u8"\ue041"
#define ICON_FA_TRAIN u8"\uf238"
#define ICON_FA_TRAM u8"\uf7da"
#define ICON_FA_TRANSGENDER u8"\uf224"
#define ICON_FA_TRANSGENDER_ALT u8"\uf225"
#define ICON_FA_TRANSPORTER u8"\ue042"
#define ICON_FA_TRANSPORTER_1 u8"\ue043"
#define ICON_FA_TRANSPORTER_2 u8"\ue044"
#define ICON_FA_TRANSPORTER_3 u8"\ue045"
#define ICON_FA_TRANSPORTER_EMPTY u8"\ue046"
#define ICON_FA_TRASH u8"\uf1f8"
#define ICON_FA_TRASH_ALT u8"\uf2ed"
#define ICON_FA_TRASH_RESTORE u8"\uf829"
#define ICON_FA_TRASH_RESTORE_ALT u8"\uf82a"
#define ICON_FA_TRASH_UNDO u8"\uf895"
#define ICON_FA_TRASH_UNDO_ALT u8"\uf896"
#define ICON_FA_TREASURE_CHEST u8"\uf723"
#define ICON_FA_TREE u8"\uf1bb"
#define ICON_FA_TREE_ALT u8"\uf400"
#define ICON_FA_TREE_CHRISTMAS u8"\uf7db"
#define ICON_FA_TREE_DECORATED u8"\uf7dc"
#define ICON_FA_TREE_LARGE u8"\uf7dd"
#define ICON_FA_TREE_PALM u8"\uf82b"
#define ICON_FA_TREES u8"\uf724"
#define ICON_FA_TRIANGLE u8"\uf2ec"
#define ICON_FA_TRIANGLE_MUSIC u8"\uf8e2"
#define ICON_FA_TROPHY u8"\uf091"
#define ICON_FA_TROPHY_ALT u8"\uf2eb"
#define ICON_FA_TRUCK u8"\uf0d1"
#define ICON_FA_TRUCK_CONTAINER u8"\uf4dc"
#define ICON_FA_TRUCK_COUCH u8"\uf4dd"
#define ICON_FA_TRUCK_LOADING u8"\uf4de"
#define ICON_FA_TRUCK_MONSTER u8"\uf63b"
#define ICON_FA_TRUCK_MOVING u8"\uf4df"
#define ICON_FA_TRUCK_PICKUP u8"\uf63c"
#define ICON_FA_TRUCK_PLOW u8"\uf7de"
#define ICON_FA_TRUCK_RAMP u8"\uf4e0"
#define ICON_FA_TRUMPET u8"\uf8e3"
#define ICON_FA_TSHIRT u8"\uf553"
#define ICON_FA_TTY u8"\uf1e4"
#define ICON_FA_TURKEY u8"\uf725"
#define ICON_FA_TURNTABLE u8"\uf8e4"
#define ICON_FA_TURTLE u8"\uf726"
#define ICON_FA_TV u8"\uf26c"
#define ICON_FA_TV_ALT u8"\uf8e5"
#define ICON_FA_TV_MUSIC u8"\uf8e6"
#define ICON_FA_TV_RETRO u8"\uf401"
#define ICON_FA_TYPEWRITER u8"\uf8e7"
#define ICON_FA_UFO u8"\ue047"
#define ICON_FA_UFO_BEAM u8"\ue048"
#define ICON_FA_UMBRELLA u8"\uf0e9"
#define ICON_FA_UMBRELLA_BEACH u8"\uf5ca"
#define ICON_FA_UNDERLINE u8"\uf0cd"
#define ICON_FA_UNDO u8"\uf0e2"
#define ICON_FA_UNDO_ALT u8"\uf2ea"
#define ICON_FA_UNICORN u8"\uf727"
#define ICON_FA_UNION u8"\uf6a2"
#define ICON_FA_UNIVERSAL_ACCESS u8"\uf29a"
#define ICON_FA_UNIVERSITY u8"\uf19c"
#define ICON_FA_UNLINK u8"\uf127"
#define ICON_FA_UNLOCK u8"\uf09c"
#define ICON_FA_UNLOCK_ALT u8"\uf13e"
#define ICON_FA_UPLOAD u8"\uf093"
#define ICON_FA_USB_DRIVE u8"\uf8e9"
#define ICON_FA_USD_CIRCLE u8"\uf2e8"
#define ICON_FA_USD_SQUARE u8"\uf2e9"
#define ICON_FA_USER u8"\uf007"
#define ICON_FA_USER_ALIEN u8"\ue04a"
#define ICON_FA_USER_ALT u8"\uf406"
#define ICON_FA_USER_ALT_SLASH u8"\uf4fa"
#define ICON_FA_USER_ASTRONAUT u8"\uf4fb"
#define ICON_FA_USER_CHART u8"\uf6a3"
#define ICON_FA_USER_CHECK u8"\uf4fc"
#define ICON_FA_USER_CIRCLE u8"\uf2bd"
#define ICON_FA_USER_CLOCK u8"\uf4fd"
#define ICON_FA_USER_COG u8"\uf4fe"
#define ICON_FA_USER_COWBOY u8"\uf8ea"
#define ICON_FA_USER_CROWN u8"\uf6a4"
#define ICON_FA_USER_EDIT u8"\uf4ff"
#define ICON_FA_USER_FRIENDS u8"\uf500"
#define ICON_FA_USER_GRADUATE u8"\uf501"
#define ICON_FA_USER_HARD_HAT u8"\uf82c"
#define ICON_FA_USER_HEADSET u8"\uf82d"
#define ICON_FA_USER_INJURED u8"\uf728"
#define ICON_FA_USER_LOCK u8"\uf502"
#define ICON_FA_USER_MD u8"\uf0f0"
#define ICON_FA_USER_MD_CHAT u8"\uf82e"
#define ICON_FA_USER_MINUS u8"\uf503"
#define ICON_FA_USER_MUSIC u8"\uf8eb"
#define ICON_FA_USER_NINJA u8"\uf504"
#define ICON_FA_USER_NURSE u8"\uf82f"
#define ICON_FA_USER_PLUS u8"\uf234"
#define ICON_FA_USER_ROBOT u8"\ue04b"
#define ICON_FA_USER_SECRET u8"\uf21b"
#define ICON_FA_USER_SHIELD u8"\uf505"
#define ICON_FA_USER_SLASH u8"\uf506"
#define ICON_FA_USER_TAG u8"\uf507"
#define ICON_FA_USER_TIE u8"\uf508"
#define ICON_FA_USER_TIMES u8"\uf235"
#define ICON_FA_USER_UNLOCK u8"\ue058"
#define ICON_FA_USER_VISOR u8"\ue04c"
#define ICON_FA_USERS u8"\uf0c0"
#define ICON_FA_USERS_CLASS u8"\uf63d"
#define ICON_FA_USERS_COG u8"\uf509"
#define ICON_FA_USERS_CROWN u8"\uf6a5"
#define ICON_FA_USERS_MEDICAL u8"\uf830"
#define ICON_FA_USERS_SLASH u8"\ue073"
#define ICON_FA_UTENSIL_FORK u8"\uf2e3"
#define ICON_FA_UTENSIL_KNIFE u8"\uf2e4"
#define ICON_FA_UTENSIL_SPOON u8"\uf2e5"
#define ICON_FA_UTENSILS u8"\uf2e7"
#define ICON_FA_UTENSILS_ALT u8"\uf2e6"
#define ICON_FA_VACUUM u8"\ue04d"
#define ICON_FA_VACUUM_ROBOT u8"\ue04e"
#define ICON_FA_VALUE_ABSOLUTE u8"\uf6a6"
#define ICON_FA_VECTOR_SQUARE u8"\uf5cb"
#define ICON_FA_VENUS u8"\uf221"
#define ICON_FA_VENUS_DOUBLE u8"\uf226"
#define ICON_FA_VENUS_MARS u8"\uf228"
#define ICON_FA_VHS u8"\uf8ec"
#define ICON_FA_VIAL u8"\uf492"
#define ICON_FA_VIALS u8"\uf493"
#define ICON_FA_VIDEO u8"\uf03d"
#define ICON_FA_VIDEO_PLUS u8"\uf4e1"
#define ICON_FA_VIDEO_SLASH u8"\uf4e2"
#define ICON_FA_VIHARA u8"\uf6a7"
#define ICON_FA_VIOLIN u8"\uf8ed"
#define ICON_FA_VIRUS u8"\ue074"
#define ICON_FA_VIRUS_SLASH u8"\ue075"
#define ICON_FA_VIRUSES u8"\ue076"
#define ICON_FA_VOICEMAIL u8"\uf897"
#define ICON_FA_VOLCANO u8"\uf770"
#define ICON_FA_VOLLEYBALL_BALL u8"\uf45f"
#define ICON_FA_VOLUME u8"\uf6a8"
#define ICON_FA_VOLUME_DOWN u8"\uf027"
#define ICON_FA_VOLUME_MUTE u8"\uf6a9"
#define ICON_FA_VOLUME_OFF u8"\uf026"
#define ICON_FA_VOLUME_SLASH u8"\uf2e2"
#define ICON_FA_VOLUME_UP u8"\uf028"
#define ICON_FA_VOTE_NAY u8"\uf771"
#define ICON_FA_VOTE_YEA u8"\uf772"
#define ICON_FA_VR_CARDBOARD u8"\uf729"
#define ICON_FA_WAGON_COVERED u8"\uf8ee"
#define ICON_FA_WALKER u8"\uf831"
#define ICON_FA_WALKIE_TALKIE u8"\uf8ef"
#define ICON_FA_WALKING u8"\uf554"
#define ICON_FA_WALLET u8"\uf555"
#define ICON_FA_WAND u8"\uf72a"
#define ICON_FA_WAND_MAGIC u8"\uf72b"
#define ICON_FA_WAREHOUSE u8"\uf494"
#define ICON_FA_WAREHOUSE_ALT u8"\uf495"
#define ICON_FA_WASHER u8"\uf898"
#define ICON_FA_WATCH u8"\uf2e1"
#define ICON_FA_WATCH_CALCULATOR u8"\uf8f0"
#define ICON_FA_WATCH_FITNESS u8"\uf63e"
#define ICON_FA_WATER u8"\uf773"
#define ICON_FA_WATER_LOWER u8"\uf774"
#define ICON_FA_WATER_RISE u8"\uf775"
#define ICON_FA_WAVE_SINE u8"\uf899"
#define ICON_FA_WAVE_SQUARE u8"\uf83e"
#define ICON_FA_WAVE_TRIANGLE u8"\uf89a"
#define ICON_FA_WAVEFORM u8"\uf8f1"
#define ICON_FA_WAVEFORM_PATH u8"\uf8f2"
#define ICON_FA_WEBCAM u8"\uf832"
#define ICON_FA_WEBCAM_SLASH u8"\uf833"
#define ICON_FA_WEIGHT u8"\uf496"
#define ICON_FA_WEIGHT_HANGING u8"\uf5cd"
#define ICON_FA_WHALE u8"\uf72c"
#define ICON_FA_WHEAT u8"\uf72d"
#define ICON_FA_WHEELCHAIR u8"\uf193"
#define ICON_FA_WHISTLE u8"\uf460"
#define ICON_FA_WIFI u8"\uf1eb"
#define ICON_FA_WIFI_1 u8"\uf6aa"
#define ICON_FA_WIFI_2 u8"\uf6ab"
#define ICON_FA_WIFI_SLASH u8"\uf6ac"
#define ICON_FA_WIND u8"\uf72e"
#define ICON_FA_WIND_TURBINE u8"\uf89b"
#define ICON_FA_WIND_WARNING u8"\uf776"
#define ICON_FA_WINDOW u8"\uf40e"
#define ICON_FA_WINDOW_ALT u8"\uf40f"
#define ICON_FA_WINDOW_CLOSE u8"\uf410"
#define ICON_FA_WINDOW_FRAME u8"\ue04f"
#define ICON_FA_WINDOW_FRAME_OPEN u8"\ue050"
#define ICON_FA_WINDOW_MAXIMIZE u8"\uf2d0"
#define ICON_FA_WINDOW_MINIMIZE u8"\uf2d1"
#define ICON_FA_WINDOW_RESTORE u8"\uf2d2"
#define ICON_FA_WINDSOCK u8"\uf777"
#define ICON_FA_WINE_BOTTLE u8"\uf72f"
#define ICON_FA_WINE_GLASS u8"\uf4e3"
#define ICON_FA_WINE_GLASS_ALT u8"\uf5ce"
#define ICON_FA_WON_SIGN u8"\uf159"
#define ICON_FA_WREATH u8"\uf7e2"
#define ICON_FA_WRENCH u8"\uf0ad"
#define ICON_FA_X_RAY u8"\uf497"
#define ICON_FA_YEN_SIGN u8"\uf157"
#define ICON_FA_YIN_YANG u8"\uf6ad"
